var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, EventEmitter, HostBinding, Inject, Injectable, InjectionToken, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { BehaviorSubject as BehaviorSubject$1 } from 'rxjs/BehaviorSubject';
import { FormBuilder, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { Http } from '@angular/http';
import 'rxjs/add/operator/map';
var SimulatorState = (function () {
    function SimulatorState() {
        this.nonRelevantDataElementIds = [];
        this.endPointId = '';
        this.selectedDecisionPointId = '';
        this.selectedDecisionPointLabel = '';
        this.selectedBranchLabel = '';
    }
    return SimulatorState;
}());
var DataElementValues = (function () {
    /**
     * @param {?} values
     */
    function DataElementValues(values) {
        this.values = values;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    DataElementValues.prototype.addOrUpdate = function (key, value) {
        this.values[key] = value;
    };
    /**
     * @param {?} key
     * @return {?}
     */
    DataElementValues.prototype.get = function (key) {
        return this.values[key];
    };
    /**
     * @param {?} key
     * @return {?}
     */
    DataElementValues.prototype.delete = function (key) {
        return this.values.delete(key);
    };
    /**
     * @return {?}
     */
    DataElementValues.prototype.getAll = function () {
        return this.values;
    };
    return DataElementValues;
}());
var SimulatorEngineService = (function () {
    function SimulatorEngineService() {
        this.endOfRoadReached = false;
        this.lastConditionMetBranchLevel = 1;
        this.simulatorStateChanged = new BehaviorSubject$1(new SimulatorState());
        this.dataElementValues = new Map();
        this.dataElementTexts = new Map();
    }
    /**
     * @return {?}
     */
    SimulatorEngineService.prototype.getAllDataElementValues = function () {
        return this.dataElementValues;
    };
    /**
     * @return {?}
     */
    SimulatorEngineService.prototype.getAllDataElementTexts = function () {
        return this.dataElementTexts;
    };
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    SimulatorEngineService.prototype.getDataElementValue = function (dataElementId) {
        return this.dataElementValues[dataElementId];
    };
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    SimulatorEngineService.prototype.getDataElementText = function (dataElementId) {
        return this.dataElementTexts[dataElementId];
    };
    /**
     * @param {?} dataElementId
     * @param {?} value
     * @param {?} text
     * @return {?}
     */
    SimulatorEngineService.prototype.addOrUpdateDataElement = function (dataElementId, value, text) {
        this.dataElementValues[dataElementId] = value;
        this.dataElementTexts[dataElementId] = text;
        this.evaluateDecisionPoints();
    };
    /**
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @param {?=} nonRelevantDataElementIds
     * @return {?}
     */
    SimulatorEngineService.prototype.evaluateDecisionPoint = function (decisionPoint, branchingLevel, nonRelevantDataElementIds) {
        if (nonRelevantDataElementIds === void 0) { nonRelevantDataElementIds = []; }
        var /** @type {?} */ currentBranchCount = 0;
        var /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (var _a = 0, _b = decisionPoint.branches; _a < _b.length; _a++) {
            var branch = _b[_a];
            currentBranchCount++;
            var /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            // console.log( 'Decision Point:- ' + decisionPoint.id +  ', Branch:- ' + branch.label + ', Condition Met :- ' + conditionMet);
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (nonRelevantDataElementIds === undefined) {
                    nonRelevantDataElementIds = new Array();
                }
                if (branch.notRelevantDataElements !== undefined) {
                    for (var _c = 0, _d = branch.notRelevantDataElements.dataElementReferences; _c < _d.length; _c++) {
                        var nonRelevantDataElementReference = _d[_c];
                        nonRelevantDataElementIds.push(nonRelevantDataElementReference.dataElementId);
                    }
                }
                if (branch.decisionPoints !== undefined) {
                    for (var _e = 0, _f = branch.decisionPoints; _e < _f.length; _e++) {
                        var branchDecisionPoint = _f[_e];
                        var /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateDecisionPoint(branchDecisionPoint, newBranchingLevel, nonRelevantDataElementIds);
                    }
                }
                else if (branch.endPointRef !== undefined) {
                    var /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.endPointId = branch.endPointRef.endPointId;
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    simulatorState.selectedBranchLabel = branch.label;
                    simulatorState.selectedDecisionPointId = decisionPoint.id;
                    simulatorState.selectedDecisionPointLabel = decisionPoint.label;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    var /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    return;
                }
                else {
                    continue;
                }
            }
        }
    };
    /**
     * @param {?} nonRelevantDataElementIds
     * @return {?}
     */
    SimulatorEngineService.prototype.resetValuesOfNonRelevantDataElements = function (nonRelevantDataElementIds) {
        for (var _a = 0, nonRelevantDataElementIds_1 = nonRelevantDataElementIds; _a < nonRelevantDataElementIds_1.length; _a++) {
            var nonRelevantDataElementId = nonRelevantDataElementIds_1[_a];
            var /** @type {?} */ defaultValue = void 0;
            for (var _b = 0, _c = this.template.dataElements; _b < _c.length; _b++) {
                var dataElement = _c[_b];
                if (dataElement.id === nonRelevantDataElementId) {
                    defaultValue = dataElement.defaultValue;
                    break;
                }
            }
            this.dataElementValues[nonRelevantDataElementId] = defaultValue;
        }
    };
    /**
     * @param {?} elementId
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @return {?}
     */
    SimulatorEngineService.prototype.evaluateComputedElementDecisionPoint = function (elementId, decisionPoint, branchingLevel) {
        var /** @type {?} */ currentBranchCount = 0;
        var /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (var _a = 0, _b = decisionPoint.branches; _a < _b.length; _a++) {
            var branch = _b[_a];
            currentBranchCount++;
            var /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (branch.decisionPoints !== undefined) {
                    for (var _c = 0, _d = branch.decisionPoints; _c < _d.length; _c++) {
                        var branchDecisionPoint = _d[_c];
                        var /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateComputedElementDecisionPoint(elementId, branchDecisionPoint, newBranchingLevel);
                    }
                }
                else if (branch.computedValue !== undefined) {
                    this.dataElementValues[elementId] = branch.computedValue.expressionText;
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    this.dataElementValues[elementId] = undefined;
                    return;
                }
                else {
                    continue;
                }
            }
        }
    };
    /**
     * @return {?}
     */
    SimulatorEngineService.prototype.evaluateComputedExpressions = function () {
        this.endOfRoadReached = false;
        for (var _a = 0, _b = this.template.dataElements; _a < _b.length; _a++) {
            var element = _b[_a];
            if (element.dataElementType === 'ComputedDataElement') {
                var /** @type {?} */ computedElement = (element);
                for (var _c = 0, _d = computedElement.decisionPoints; _c < _d.length; _c++) {
                    var decisionPoint = _d[_c];
                    this.evaluateComputedElementDecisionPoint(element.id, decisionPoint, 1);
                    if (this.dataElementValues[element.id] === undefined && decisionPoint.defaultBranch &&
                        decisionPoint.defaultBranch.computedValue) {
                        this.dataElementValues[element.id] = decisionPoint.defaultBranch.computedValue.expressionText;
                    }
                    this.endOfRoadReached = false;
                }
            }
        }
    };
    /**
     * @return {?}
     */
    SimulatorEngineService.prototype.evaluateDecisionPoints = function () {
        console.log(this.dataElementValues);
        this.evaluateComputedExpressions();
        this.endOfRoadReached = false;
        for (var _a = 0, _b = this.template.rules.decisionPoints; _a < _b.length; _a++) {
            var decisionPoint = _b[_a];
            if (this.evaluateDecisionPoint(decisionPoint, 1, new Array())) {
                break;
            }
        }
    };
    /**
     * @param {?} template
     * @return {?}
     */
    SimulatorEngineService.prototype.initialize = function (template) {
        this.template = template;
        for (var _a = 0, _b = this.template.dataElements; _a < _b.length; _a++) {
            var dataElement = _b[_a];
            this.dataElementValues[dataElement.id] = dataElement.currentValue;
        }
    };
    return SimulatorEngineService;
}());
SimulatorEngineService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SimulatorEngineService.ctorParameters = function () { return []; };
var CoreModule = (function () {
    function CoreModule() {
    }
    /**
     * @return {?}
     */
    CoreModule.forRoot = function () {
        return {
            ngModule: CoreModule,
            providers: [SimulatorEngineService]
        };
    };
    return CoreModule;
}());
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: []
            },] },
];
/**
 * @nocollapse
 */
CoreModule.ctorParameters = function () { return []; };
var Template = (function () {
    function Template() {
    }
    return Template;
}());
var Metadata = (function () {
    function Metadata() {
    }
    return Metadata;
}());
var Diagram = (function () {
    function Diagram() {
    }
    return Diagram;
}());
var ArrayCheckerService = (function () {
    function ArrayCheckerService() {
    }
    /**
     * @param {?} item
     * @return {?}
     */
    ArrayCheckerService.prototype.isArray = function (item) {
        return item instanceof Array;
    };
    return ArrayCheckerService;
}());
ArrayCheckerService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ArrayCheckerService.ctorParameters = function () { return []; };
var DiagramService = (function () {
    /**
     * @param {?} arrayCheckerSeviceService
     */
    function DiagramService(arrayCheckerSeviceService) {
        this.arrayCheckerSeviceService = arrayCheckerSeviceService;
    }
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    DiagramService.prototype.returnDiagram = function (diagramJSON) {
        var /** @type {?} */ diagram = new Diagram();
        if (diagramJSON.Attr) {
            diagram.displaySequence = diagramJSON.Attr.DisplaySequence;
            diagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        }
        else {
            diagram.displaySequence = undefined;
            diagram.keyDiagram = false;
        }
        diagram.label = diagramJSON.Label;
        diagram.location = diagramJSON.Location;
        return diagram;
    };
    /**
     * @param {?} diagramsAsJSON
     * @return {?}
     */
    DiagramService.prototype.returnDiagrams = function (diagramsAsJSON) {
        var /** @type {?} */ diagrams = new Array();
        if (diagramsAsJSON !== undefined) {
            if (this.arrayCheckerSeviceService.isArray(diagramsAsJSON)) {
                for (var _a = 0, diagramsAsJSON_1 = diagramsAsJSON; _a < diagramsAsJSON_1.length; _a++) {
                    var diagram = diagramsAsJSON_1[_a];
                    diagrams.push(this.returnDiagram(diagram));
                }
            }
            else {
                diagrams.push(this.returnDiagram(diagramsAsJSON));
            }
        }
        return diagrams;
    };
    return DiagramService;
}());
DiagramService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DiagramService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
]; };
var CreationServiceInjectorToken = new InjectionToken('one');
var DecisionPoint = (function () {
    function DecisionPoint() {
    }
    return DecisionPoint;
}());
var Branch = (function () {
    function Branch() {
    }
    return Branch;
}());
var EndPointRef = (function () {
    function EndPointRef() {
    }
    return EndPointRef;
}());
var DataElementRef = (function () {
    function DataElementRef() {
    }
    return DataElementRef;
}());
var NotRelevantDataElements = (function () {
    function NotRelevantDataElements() {
    }
    return NotRelevantDataElements;
}());
var EqualCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function EqualCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    EqualCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        return value === this.conditionType.comparisonValue;
    };
    return EqualCondition;
}());
var ConditionType = (function () {
    function ConditionType() {
    }
    return ConditionType;
}());
var GreaterThanCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function GreaterThanCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    GreaterThanCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        var /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value > comparisonValue;
    };
    return GreaterThanCondition;
}());
var LessThanCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function LessThanCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    LessThanCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        var /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value < comparisonValue;
    };
    return LessThanCondition;
}());
var GreaterThanOrEqualsCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function GreaterThanOrEqualsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    GreaterThanOrEqualsCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        var /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value >= comparisonValue;
    };
    return GreaterThanOrEqualsCondition;
}());
var LessThanOrEqualsCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function LessThanOrEqualsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    LessThanOrEqualsCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        var /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value <= comparisonValue;
    };
    return LessThanOrEqualsCondition;
}());
var ContainsCondition = (function () {
    /**
     * @param {?} conditionType
     */
    function ContainsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    ContainsCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ returnValue = false;
        var /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        if (value !== undefined) {
            returnValue = value.indexOf(this.conditionType.comparisonValue) >= 0;
        }
        return returnValue;
    };
    return ContainsCondition;
}());
var AndCondition = (function () {
    function AndCondition() {
        this.conditions = [];
        this.conditionType = 'AndCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    AndCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ returnValue = true;
        for (var /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            var /** @type {?} */ condition = this.conditions[conditionCounter];
            var /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (!executedCondition) ? false : (returnValue && executedCondition);
            if (!returnValue) {
                break;
            }
        }
        return returnValue;
    };
    return AndCondition;
}());
var OrCondition = (function () {
    function OrCondition() {
        this.conditions = [];
        this.conditionType = 'OrCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    OrCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ returnValue = false;
        for (var /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            var /** @type {?} */ condition = this.conditions[conditionCounter];
            var /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (returnValue || executedCondition);
            if (returnValue) {
                break;
            }
        }
        return returnValue;
    };
    return OrCondition;
}());
var NotCondition = (function () {
    function NotCondition() {
        this.conditions = [];
        this.conditionType = 'NotCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    NotCondition.prototype.evaluate = function (dataElementValues) {
        var /** @type {?} */ results = new Array();
        for (var _a = 0, _b = this.conditions; _a < _b.length; _a++) {
            var condition = _b[_a];
            results.push(condition.evaluate(dataElementValues));
        }
        return !(results[0]);
    };
    return NotCondition;
}());
var ConditionsCreationService = (function () {
    /**
     * @param {?} arrayCheckerService
     */
    function ConditionsCreationService(arrayCheckerService) {
        this.arrayCheckerService = arrayCheckerService;
    }
    /**
     * @param {?} conditionJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.returnConditionType = function (conditionJSON) {
        var /** @type {?} */ conditionType = new ConditionType();
        conditionType.comparisonValue = conditionJSON.Attr.ComparisonValue;
        conditionType.dataElementId = conditionJSON.Attr.DataElementId;
        return conditionType;
    };
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.returnCondition = function (branchJSON) {
        var /** @type {?} */ condition;
        if (branchJSON.hasOwnProperty('EqualCondition')) {
            condition = new EqualCondition(this.returnConditionType(branchJSON.EqualCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanCondition')) {
            condition = new GreaterThanCondition(this.returnConditionType(branchJSON.GreaterThanCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanCondition')) {
            condition = new LessThanCondition(this.returnConditionType(branchJSON.LessThanCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanOrEqualsCondition')) {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(branchJSON.GreaterThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanOrEqualsCondition')) {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(branchJSON.LessThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('ContainsCondition')) {
            condition = new ContainsCondition(this.returnConditionType(branchJSON.ContainsCondition));
        }
        return condition;
    };
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.isComposite = function (compositeElementJSON) {
        return compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
    };
    /**
     * @param {?} conditionIdentifier
     * @param {?} conditionJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.returnConditionFromJSON = function (conditionIdentifier, conditionJSON) {
        var /** @type {?} */ condition;
        if (conditionIdentifier === 'EqualCondition') {
            condition = new EqualCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanCondition') {
            condition = new GreaterThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanCondition') {
            condition = new LessThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanOrEqualsCondition') {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanOrEqualsCondition') {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'ContainsCondition') {
            condition = new ContainsCondition(this.returnConditionType(conditionJSON));
        }
        return condition;
    };
    /**
     * @param {?} conditionsJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.returnConditions = function (conditionsJSON) {
        var /** @type {?} */ conditions;
        var /** @type {?} */ conditionIdentifiers = ['EqualCondition', 'GreaterThanCondition', 'LessThanCondition',
            'GreaterThanOrEqualsCondition', 'LessThanOrEqualsCondition', 'ContainsCondition'];
        for (var _a = 0, conditionIdentifiers_1 = conditionIdentifiers; _a < conditionIdentifiers_1.length; _a++) {
            var conditionIdentifier = conditionIdentifiers_1[_a];
            var /** @type {?} */ conditionJSON = conditionsJSON[conditionIdentifier];
            if (conditionJSON !== undefined) {
                conditions = new Array();
                if (this.arrayCheckerService.isArray(conditionJSON)) {
                    for (var _b = 0, conditionJSON_1 = conditionJSON; _b < conditionJSON_1.length; _b++) {
                        var jsonValue = conditionJSON_1[_b];
                        conditions.push(this.returnConditionFromJSON(conditionIdentifier, jsonValue));
                    }
                }
                else {
                    conditions.push(this.returnConditionFromJSON(conditionIdentifier, conditionJSON));
                }
            }
        }
        return conditions;
    };
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    ConditionsCreationService.prototype.isHybrid = function (compositeElementJSON) {
        var /** @type {?} */ compositeExists = compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
        var /** @type {?} */ primitiveExists = compositeElementJSON.hasOwnProperty('EqualCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('ContainsCondition');
        return compositeExists && primitiveExists;
    };
    /**
     * @param {?} data
     * @return {?}
     */
    ConditionsCreationService.prototype.returnCompositeCondition = function (data) {
        if (!this.isComposite(data)) {
            return;
        }
        var /** @type {?} */ compositeConditionJSON;
        var /** @type {?} */ compositeCondition;
        if (data.hasOwnProperty('AndCondition')) {
            compositeConditionJSON = data.AndCondition;
            compositeCondition = new AndCondition();
        }
        else if (data.hasOwnProperty('OrCondition')) {
            compositeConditionJSON = data.OrCondition;
            compositeCondition = new OrCondition();
        }
        else if (data.hasOwnProperty('NotCondition')) {
            compositeConditionJSON = data.NotCondition;
            compositeCondition = new NotCondition();
        }
        if (!this.isComposite(compositeConditionJSON)) {
            compositeCondition.conditions = this.returnConditions(compositeConditionJSON);
        }
        else if (this.isHybrid(compositeConditionJSON)) {
            var /** @type {?} */ jsonKeys = Object.keys(compositeConditionJSON);
            for (var _a = 0, jsonKeys_1 = jsonKeys; _a < jsonKeys_1.length; _a++) {
                var jsonKey = jsonKeys_1[_a];
                var /** @type {?} */ jsonValue = compositeConditionJSON[jsonKey];
                var /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                var /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, compositeCondition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (var _b = 0, jsonValue_1 = jsonValue; _b < jsonValue_1.length; _b++) {
                            var arrayValue = jsonValue_1[_b];
                            compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else {
            this.returnInnerConditions(compositeConditionJSON, compositeCondition);
        }
        return compositeCondition;
    };
    /**
     * @param {?} elementName
     * @return {?}
     */
    ConditionsCreationService.prototype.returnCompositeConditionFromName = function (elementName) {
        var /** @type {?} */ compositeCondition;
        switch (elementName) {
            case 'AndCondition':
                {
                    compositeCondition = new AndCondition();
                    break;
                }
            case 'OrCondition':
                {
                    compositeCondition = new OrCondition();
                    break;
                }
            case 'NotCondition':
                {
                    compositeCondition = new NotCondition();
                }
        }
        return compositeCondition;
    };
    /**
     * @param {?} key
     * @param {?} value
     * @param {?} compositeCondition
     * @return {?}
     */
    ConditionsCreationService.prototype.addConditionsToInnerConditions = function (key, value, compositeCondition) {
        var /** @type {?} */ condition = this.returnCompositeConditionFromName(key);
        compositeCondition.conditions.push(condition);
        if (this.isHybrid(value)) {
            var /** @type {?} */ jsonKeys = Object.keys(value);
            for (var _a = 0, jsonKeys_2 = jsonKeys; _a < jsonKeys_2.length; _a++) {
                var jsonKey = jsonKeys_2[_a];
                var /** @type {?} */ jsonValue = value[jsonKey];
                var /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                var /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, condition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (var _b = 0, jsonValue_2 = jsonValue; _b < jsonValue_2.length; _b++) {
                            var arrayValue = jsonValue_2[_b];
                            condition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        condition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else if (this.isComposite(value)) {
            // console.log( 'isComposite');
        }
        else {
            condition.conditions = this.returnConditions(value);
        }
    };
    /**
     * @param {?} innerConditionsJSON
     * @param {?} compositeCondition
     * @return {?}
     */
    ConditionsCreationService.prototype.returnInnerConditions = function (innerConditionsJSON, compositeCondition) {
        var /** @type {?} */ jsonKeys = Object.keys(innerConditionsJSON);
        for (var _a = 0, jsonKeys_3 = jsonKeys; _a < jsonKeys_3.length; _a++) {
            var key = jsonKeys_3[_a];
            var /** @type {?} */ values = innerConditionsJSON[key];
            if (this.arrayCheckerService.isArray(values)) {
                for (var _b = 0, values_1 = values; _b < values_1.length; _b++) {
                    var value = values_1[_b];
                    this.addConditionsToInnerConditions(key, value, compositeCondition);
                }
            }
            else {
                this.addConditionsToInnerConditions(key, innerConditionsJSON[key], compositeCondition);
            }
        }
    };
    return ConditionsCreationService;
}());
ConditionsCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ConditionsCreationService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
]; };
var TextExpression = (function () {
    function TextExpression() {
    }
    return TextExpression;
}());
var ArithmeticExpression = (function () {
    function ArithmeticExpression() {
    }
    return ArithmeticExpression;
}());
var ComputedValueCreationService = (function () {
    function ComputedValueCreationService() {
    }
    /**
     * @param {?} dataAsJSON
     * @return {?}
     */
    ComputedValueCreationService.prototype.createComputedValue = function (dataAsJSON) {
        if (dataAsJSON['TextExpression'] !== undefined) {
            var /** @type {?} */ computedValue = new TextExpression();
            computedValue.expressionText = dataAsJSON.TextExpression;
            return computedValue;
        }
        if (dataAsJSON['ArithmeticExpression'] !== undefined) {
            {
                var /** @type {?} */ computedValue = new ArithmeticExpression();
                computedValue.expressionText = dataAsJSON.ArithmeticExpression;
                return computedValue;
            }
        }
    };
    return ComputedValueCreationService;
}());
ComputedValueCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ComputedValueCreationService.ctorParameters = function () { return []; };
var DecisionPointsCreationService = (function () {
    /**
     * @param {?} arrayCheckerService
     * @param {?} conditionsCreationService
     * @param {?} computedValueCreationService
     */
    function DecisionPointsCreationService(arrayCheckerService, conditionsCreationService, computedValueCreationService) {
        this.arrayCheckerService = arrayCheckerService;
        this.conditionsCreationService = conditionsCreationService;
        this.computedValueCreationService = computedValueCreationService;
    }
    /**
     * @param {?} dataElementRefJSON
     * @return {?}
     */
    DecisionPointsCreationService.prototype.createRelevantDataElementReferences = function (dataElementRefJSON) {
        var /** @type {?} */ dataElementRef = new DataElementRef();
        dataElementRef.dataElementId = dataElementRefJSON.Attr.DataElementId;
        return dataElementRef;
    };
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    DecisionPointsCreationService.prototype.returnBranch = function (branchJSON) {
        var /** @type {?} */ branch = new Branch();
        branch.label = branchJSON.Label;
        if (branchJSON.EndPointRef) {
            branch.endPointRef = new EndPointRef();
            branch.endPointRef.endPointId = branchJSON.EndPointRef.Attr.EndPointId;
        }
        branch.condition = this.conditionsCreationService.returnCondition(branchJSON);
        branch.computedValue = this.computedValueCreationService.createComputedValue(branchJSON);
        if (this.conditionsCreationService.isComposite(branchJSON)) {
            branch.compositeCondition = this.conditionsCreationService.returnCompositeCondition(branchJSON);
        }
        if (branchJSON.NotRelevantDataElements) {
            var /** @type {?} */ notRelevantDataElements = new NotRelevantDataElements();
            notRelevantDataElements.dataElementReferences = new Array();
            var /** @type {?} */ dataElementRefs = branchJSON.NotRelevantDataElements.DataElementRef;
            if (this.arrayCheckerService.isArray(dataElementRefs)) {
                for (var _a = 0, dataElementRefs_1 = dataElementRefs; _a < dataElementRefs_1.length; _a++) {
                    var dataElementRefJSON = dataElementRefs_1[_a];
                    notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefJSON));
                }
            }
            else {
                notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefs));
            }
            branch.notRelevantDataElements = notRelevantDataElements;
        }
        if (branchJSON.DecisionPoint) {
            branch.decisionPoints = new Array();
            this.addDecisionPoints(branchJSON.DecisionPoint, branch.decisionPoints);
        }
        return branch;
    };
    /**
     * @param {?} decsionPointAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    DecisionPointsCreationService.prototype.addDecisionPoint = function (decsionPointAsJSON, decisionPoints) {
        var /** @type {?} */ decisionPoint = new DecisionPoint();
        if (decsionPointAsJSON.Attr && decsionPointAsJSON.Attr.Id) {
            decisionPoint.id = decsionPointAsJSON.Attr.Id;
        }
        decisionPoint.label = decsionPointAsJSON.Label;
        var /** @type {?} */ branchesJSON = decsionPointAsJSON.Branch;
        if (branchesJSON !== undefined) {
            decisionPoint.branches = new Array();
            if (this.arrayCheckerService.isArray(branchesJSON)) {
                for (var _a = 0, branchesJSON_1 = branchesJSON; _a < branchesJSON_1.length; _a++) {
                    var branchJSON = branchesJSON_1[_a];
                    decisionPoint.branches.push(this.returnBranch(branchJSON));
                }
            }
            else {
                decisionPoint.branches.push(this.returnBranch(branchesJSON));
            }
            var /** @type {?} */ defaultBranchJSON = decsionPointAsJSON.DefaultBranch;
            if (defaultBranchJSON !== undefined) {
                decisionPoint.defaultBranch = this.createDefaultBranch(defaultBranchJSON);
            }
        }
        decisionPoints.push(decisionPoint);
    };
    /**
     * @param {?} decsionPointsAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    DecisionPointsCreationService.prototype.addDecisionPoints = function (decsionPointsAsJSON, decisionPoints) {
        if (this.arrayCheckerService.isArray(decsionPointsAsJSON)) {
            for (var _a = 0, decsionPointsAsJSON_1 = decsionPointsAsJSON; _a < decsionPointsAsJSON_1.length; _a++) {
                var decisionPoint = decsionPointsAsJSON_1[_a];
                this.addDecisionPoint(decisionPoint, decisionPoints);
            }
        }
        else {
            this.addDecisionPoint(decsionPointsAsJSON, decisionPoints);
        }
    };
    /**
     * @param {?} data
     * @return {?}
     */
    DecisionPointsCreationService.prototype.createDecisionPoints = function (data) {
        var /** @type {?} */ decisionPoints = new Array();
        this.addDecisionPoints(data, decisionPoints);
        return decisionPoints;
    };
    /**
     * @param {?} data
     * @return {?}
     */
    DecisionPointsCreationService.prototype.createDefaultBranch = function (data) {
        var /** @type {?} */ defaultBranch = new Branch();
        defaultBranch.label = 'Default Branch';
        defaultBranch.computedValue = this.computedValueCreationService.createComputedValue(data);
        return defaultBranch;
    };
    return DecisionPointsCreationService;
}());
DecisionPointsCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DecisionPointsCreationService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
    { type: ConditionsCreationService, },
    { type: ComputedValueCreationService, },
]; };
var Rules = (function () {
    function Rules() {
    }
    return Rules;
}());
var TemplatePartial = (function () {
    function TemplatePartial() {
    }
    return TemplatePartial;
}());
var TemplateManagerService = (function () {
    /**
     * @param {?} diagramService
     * @param {?} elememtcreationService
     * @param {?} arrayCheckerService
     * @param {?} decisionPointsCreationService
     */
    function TemplateManagerService(diagramService, elememtcreationService, arrayCheckerService, decisionPointsCreationService) {
        this.diagramService = diagramService;
        this.elememtcreationService = elememtcreationService;
        this.arrayCheckerService = arrayCheckerService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.endPointXMLString = [];
        this.stringParser = require('string');
    }
    /**
     * @param {?} templateContent
     * @return {?}
     */
    TemplateManagerService.prototype.getTemplate = function (templateContent) {
        var /** @type {?} */ template = new Template();
        var /** @type {?} */ templateContentAsJSON;
        templateContentAsJSON = this.parseToJson(templateContent);
        if (template === undefined) {
            throw new Error('Unable to parse the template');
        }
        template.metadata = this.getMetaData(templateContentAsJSON.Metadata);
        template.dataElements = this.getDataElements(templateContentAsJSON.DataElements);
        if (templateContentAsJSON.Rules) {
            template.rules = new Rules();
            template.rules.decisionPoints = this.decisionPointsCreationService.
                createDecisionPoints(templateContentAsJSON.Rules.DecisionPoint);
        }
        template.templatePartial = this.returnEndpoints(templateContent);
        template.endPointsString = this.endPointXMLString;
        template.xmlContent = templateContent;
        return template;
    };
    /**
     * @param {?} templatePartialJSON
     * @return {?}
     */
    TemplateManagerService.prototype.getTemplatePartial = function (templatePartialJSON) {
        var /** @type {?} */ templatePartial = new TemplatePartial;
        templatePartial.id = templatePartialJSON.Attr.Id;
        templatePartial.sectionIfNotValue = templatePartialJSON.SectionIfValueNot;
        templatePartial.sectionIfValues = templatePartialJSON.SectionIfValue;
        return templatePartial;
    };
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    TemplateManagerService.prototype.returnEndPointContents = function (content, startToken, endToken) {
        var /** @type {?} */ contents = new Array();
        var /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            var /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            var /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                var /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                var /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents.push(contentData);
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    };
    /**
     * @param {?} templatePartialArray
     * @return {?}
     */
    TemplateManagerService.prototype.returnTemplatePartials = function (templatePartialArray) {
        var /** @type {?} */ templatePartials = new Array();
        for (var _a = 0, templatePartialArray_1 = templatePartialArray; _a < templatePartialArray_1.length; _a++) {
            var arrayItem = templatePartialArray_1[_a];
            var /** @type {?} */ templatePartial = new TemplatePartial();
            var /** @type {?} */ templatePartialAsJSON = this.parseToJson(arrayItem);
            templatePartial.id = templatePartialAsJSON.Attr.Id;
        }
        return templatePartials;
    };
    /**
     * @param {?} xmlData
     * @return {?}
     */
    TemplateManagerService.prototype.returnEndpoints = function (xmlData) {
        var /** @type {?} */ endPointStartToken = '<EndPoints>';
        var /** @type {?} */ endPointEndToken = '</EndPoints>';
        var /** @type {?} */ endPointStartTokenPosition = xmlData.indexOf(endPointStartToken);
        var /** @type {?} */ endPointEndTokenPosition = xmlData.indexOf(endPointEndToken);
        if (endPointStartTokenPosition >= 0 && endPointEndTokenPosition >= 0) {
            var /** @type {?} */ contentStartPosition = (endPointStartTokenPosition + endPointStartToken.length);
            var /** @type {?} */ endPointContent = xmlData.substring(contentStartPosition, endPointEndTokenPosition);
            if (endPointContent.length > 0) {
                var /** @type {?} */ templatePartials = this.returnEndPointContents(endPointContent, '<TemplatePartial', '</TemplatePartial>');
                this.endPointXMLString = this.returnEndPointContents(endPointContent, '<EndPoint', '</EndPoint>');
                return templatePartials;
            }
        }
    };
    /**
     * @param {?} xmlData
     * @return {?}
     */
    TemplateManagerService.prototype.parseToJson = function (xmlData) {
        var /** @type {?} */ jsonResult;
        var /** @type {?} */ parseString = require('xml2js').parseString;
        parseString(xmlData, { explicitRoot: false, explicitArray: false, attrkey: 'Attr' }, function (err, result) {
            jsonResult = result;
        });
        return jsonResult;
    };
    /**
     * @param {?} metadataJSON
     * @return {?}
     */
    TemplateManagerService.prototype.getMetaData = function (metadataJSON) {
        var /** @type {?} */ metadata = new Metadata();
        metadata.label = metadataJSON.Label;
        metadata.id = metadataJSON.ID;
        metadata.schemaVersion = metadataJSON.SchemaVersion;
        metadata.ruleVersion = metadataJSON.RuleVersion;
        var /** @type {?} */ diagramsAsJSON = metadataJSON.Info.Diagrams.Diagram;
        metadata.diagrams = this.diagramService.returnDiagrams(diagramsAsJSON);
        return metadata;
    };
    /**
     * @param {?} elementType
     * @param {?} dataElementsJSON
     * @return {?}
     */
    TemplateManagerService.prototype.returnDataElement = function (elementType, dataElementsJSON) {
        var /** @type {?} */ dataElements = new Array();
        var /** @type {?} */ dataElementCreationServiceInstance;
        for (var _a = 0, _b = this.elememtcreationService; _a < _b.length; _a++) {
            var dataElementCreationService = _b[_a];
            if (dataElementCreationService.elementType === elementType) {
                dataElementCreationServiceInstance = dataElementCreationService;
                break;
            }
        }
        if (dataElementCreationServiceInstance !== undefined && dataElementsJSON !== undefined) {
            if (this.arrayCheckerService.isArray(dataElementsJSON)) {
                for (var _c = 0, dataElementsJSON_1 = dataElementsJSON; _c < dataElementsJSON_1.length; _c++) {
                    var dataElementJSON = dataElementsJSON_1[_c];
                    var /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementJSON);
                    dataElements.push(dataElement);
                }
            }
            else {
                var /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementsJSON);
                dataElements.push(dataElement);
            }
        }
        return dataElements;
    };
    /**
     * @param {?} dataElementsJSON
     * @return {?}
     */
    TemplateManagerService.prototype.getDataElements = function (dataElementsJSON) {
        var /** @type {?} */ dataElements = new Array();
        dataElements = dataElements.concat(this.returnDataElement('ChoiceDataElement', dataElementsJSON.ChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('MultiChoiceDataElement', dataElementsJSON.MultiChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('NumericDataElement', dataElementsJSON.NumericDataElement));
        dataElements = dataElements.concat(this.returnDataElement('GlobalValue', dataElementsJSON.GlobalValue));
        dataElements = dataElements.concat(this.returnDataElement('ComputedDataElement', dataElementsJSON.ComputedDataElement));
        dataElements = dataElements.concat(this.returnDataElement('IntegerDataElement', dataElementsJSON.IntegerDataElement));
        return dataElements;
    };
    return TemplateManagerService;
}());
TemplateManagerService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
TemplateManagerService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: Array, decorators: [{ type: Inject, args: [CreationServiceInjectorToken,] },] },
    { type: ArrayCheckerService, },
    { type: DecisionPointsCreationService, },
]; };
var AllTextReport = (function () {
    function AllTextReport() {
    }
    return AllTextReport;
}());
var ReportTextPosition = {};
ReportTextPosition.Down = 0;
ReportTextPosition.Right = 1;
ReportTextPosition[ReportTextPosition.Down] = "Down";
ReportTextPosition[ReportTextPosition.Right] = "Right";
var AcrAssistSimulatorComponent = (function () {
    /**
     * @param {?} templateManagerService
     * @param {?} simulatorEngineService
     */
    function AcrAssistSimulatorComponent(templateManagerService, simulatorEngineService) {
        this.templateManagerService = templateManagerService;
        this.simulatorEngineService = simulatorEngineService;
        this.returnExecutionHistory = new EventEmitter();
        this.returnDefaultElements = new EventEmitter();
        this.inputValues = [];
        this.position = ReportTextPosition;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    AcrAssistSimulatorComponent.prototype.ngOnChanges = function (changes) {
        this.isReset = true;
        this.isEmptyContent = this.templateContent === undefined || this.templateContent.length === 0 && this.inputValues.length === 0 &&
            this.inputData === undefined;
        if (this.isEmptyContent) {
            return;
        }
        if (this.inputData !== undefined) {
            if (this.inputData.length > 0) {
                this.inputValues = JSON.parse(this.inputData);
            }
        }
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        if (this.inputValues.length !== 0) {
            var _loop_1 = function (dataeElement) {
                var /** @type {?} */ inputValue = this_1.inputValues.filter(function (x) { return x.dataElementId === dataeElement.id; });
                if (inputValue !== undefined && inputValue.length > 0) {
                    dataeElement.currentValue = inputValue[0].dataElementValue;
                }
            };
            var this_1 = this;
            for (var _a = 0, _b = this.template.dataElements; _a < _b.length; _a++) {
                var dataeElement = _b[_a];
                _loop_1(/** @type {?} */ dataeElement);
            }
        }
        this.dataElements = this.template.dataElements;
        for (var /** @type {?} */ index = 0; index < this.template.metadata.diagrams.length; index++) {
            if (this.template.metadata.diagrams[index].keyDiagram) {
                var /** @type {?} */ element = new Diagram();
                element.label = this.template.metadata.diagrams[index].label;
                element.location = this.imagePath + '/' + this.template.metadata.diagrams[index].location;
                element.keyDiagram = this.template.metadata.diagrams[index].keyDiagram;
                this.keyDiagram = element;
                break;
            }
        }
        this.resultText = undefined;
    };
    /**
     * @return {?}
     */
    AcrAssistSimulatorComponent.prototype.resetElements = function () {
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        this.dataElements = this.template.dataElements;
        this.resultText = undefined;
        this.returnDefaultElements.emit();
    };
    /**
     * @param {?} textReport
     * @return {?}
     */
    AcrAssistSimulatorComponent.prototype.recieveReportText = function (textReport) {
        this.resultText = textReport;
    };
    /**
     * @param {?} finalExecutionHistory
     * @return {?}
     */
    AcrAssistSimulatorComponent.prototype.recievedExecutionHistory = function (finalExecutionHistory) {
        this.returnExecutionHistory.emit(finalExecutionHistory);
    };
    return AcrAssistSimulatorComponent;
}());
AcrAssistSimulatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-simulator',
                template: "\n    <ng-container *ngIf=\"!isEmptyContent\">\n  \n      <div class=\"row\">\n        <div class=\"text-right border-0\">\n          <h4>\n            <button class=\"btn btn-md\" (click)=\"resetElements()\">\n              <strong>Reset Data</strong>\n            </button>\n          </h4>\n        </div>\n      </div>\n  \n      <div class=\"row content-area\" >\n        <div [ngClass]=\"{'col-sm-6' : reportTextPosition == position.Right ? true : false, 'col-sm-12' : reportTextPosition == position.Right ? false : true}\" class=\"text-right border-0\">\n          <ng-container>\n            <acr-assist-data-element [dataElements]=\"dataElements\" [templatePartial]=\"template.templatePartial\" [endPointXMLString]=\"template.endPointsString\"\n              [imagePath]=\"imagePath\" [xmlContent]=\"template.xmlContent\" (returnReportText)='recieveReportText($event)' [inputValues]=\"inputValues\"\n              [isReset]=\"isReset\" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>\n          </ng-container>\n        </div>\n\n        <div class=\"col-sm-6 text-right border-0 fixed-report-text-sidebar\" *ngIf=\"reportTextPosition == position.Right\">\n          <div class=\"row report-text-top-margin left-margin\">\n            <ng-container *ngIf=\"resultText !== undefined\">\n              <acr-assist-report-text [reportText]=\"resultText\"></acr-assist-report-text>\n            </ng-container>\n          </div>\n          <div *ngIf=\" showKeyDiagram === true && keyDiagram !== undefined\" class=\"keydiagram\">\n              <img class=\"img-max-width\" src=\"{{keyDiagram.location}}\">\n          </div>\n        </div>\n\n        <div class=\"col-sm-8 report-text-top-margin\" *ngIf=\"reportTextPosition == position.Down\">\n          <ng-container *ngIf=\"resultText !== undefined\">\n            <acr-assist-report-text [reportText]=\"resultText\"></acr-assist-report-text>\n          </ng-container>\n        </div>\n      </div>\n    </ng-container>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AcrAssistSimulatorComponent.ctorParameters = function () { return [
    { type: TemplateManagerService, },
    { type: SimulatorEngineService, },
]; };
AcrAssistSimulatorComponent.propDecorators = {
    'templateContent': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'showKeyDiagram': [{ type: Input },],
    'reportTextPosition': [{ type: Input },],
    'returnExecutionHistory': [{ type: Output },],
    'returnDefaultElements': [{ type: Output },],
    'inputValues': [{ type: Input },],
    'inputData': [{ type: Input },],
};
/**
 * @abstract
 */
var DataElementCreationBaseService = (function () {
    /**
     * @param {?} diagramService
     */
    function DataElementCreationBaseService(diagramService) {
        this.diagramService = diagramService;
    }
    /**
     * @abstract
     * @param {?} data
     * @return {?}
     */
    DataElementCreationBaseService.prototype.createElement = function (data) { };
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    DataElementCreationBaseService.prototype.returnDiagram = function (diagramJSON) {
        var /** @type {?} */ metadataDiagram = new Diagram();
        metadataDiagram.displaySequence = diagramJSON.Attr.DisplaySequence;
        metadataDiagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        metadataDiagram.label = diagramJSON.Label;
        metadataDiagram.location = diagramJSON.Location;
        return metadataDiagram;
    };
    /**
     * @param {?} data
     * @param {?} dataElement
     * @return {?}
     */
    DataElementCreationBaseService.prototype.populateBasicData = function (data, dataElement) {
        dataElement.dataElementType = this.elementType;
        dataElement.displaySequence = data.Attr.DisplaySequence;
        dataElement.id = data.Attr.Id;
        dataElement.isRequired = data.Attr.IsRequired === 'true' ? true : false;
        dataElement.label = data.Label;
        dataElement.hint = data.Hint;
        if (data.Diagrams) {
            dataElement.diagrams = this.diagramService.returnDiagrams(data.Diagrams.Diagram);
        }
        dataElement.currentValue = undefined;
        dataElement.defaultValue = undefined;
    };
    return DataElementCreationBaseService;
}());
DataElementCreationBaseService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DataElementCreationBaseService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var BaseDataElement = (function () {
    function BaseDataElement() {
        this.isVisible = true;
    }
    return BaseDataElement;
}());
var ChoiceDataElement = (function (_super) {
    __extends(ChoiceDataElement, _super);
    function ChoiceDataElement() {
        var _this = _super.apply(this, arguments) || this;
        _this.allowFreetext = false;
        return _this;
    }
    return ChoiceDataElement;
}(BaseDataElement));
var Choice = (function () {
    function Choice() {
    }
    return Choice;
}());
var ImageElements = (function () {
    function ImageElements() {
    }
    return ImageElements;
}());
var ImageMap = (function (_super) {
    __extends(ImageMap, _super);
    function ImageMap() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ImageMap;
}(ImageElements));
var Area = (function () {
    function Area() {
    }
    return Area;
}());
var AreaMap = (function () {
    function AreaMap() {
    }
    return AreaMap;
}());
var ChoiceDataElementCreationService = (function (_super) {
    __extends(ChoiceDataElementCreationService, _super);
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    function ChoiceDataElementCreationService(diagramService, arrayCheckerService) {
        var _this = _super.call(this, diagramService) || this;
        _this.arrayCheckerService = arrayCheckerService;
        _this.elementType = 'ChoiceDataElement';
        return _this;
    }
    /**
     * @param {?} choiceItem
     * @return {?}
     */
    ChoiceDataElementCreationService.prototype.returnChoice = function (choiceItem) {
        var /** @type {?} */ choice = new Choice();
        choice.label = choiceItem.Label;
        choice.value = choiceItem.Value;
        choice.hint = choiceItem.Hint;
        choice.reportText = choiceItem.ReportText;
        choice.default = false;
        if (choiceItem.Attr && choiceItem.Attr.IsDefault) {
            choice.default = choiceItem.Attr.IsDefault;
        }
        return choice;
    };
    /**
     * @param {?} areaJSON
     * @return {?}
     */
    ChoiceDataElementCreationService.prototype.returnArea = function (areaJSON) {
        var /** @type {?} */ area = new Area();
        area.choiceValue = areaJSON.Attr.ChoiceValue;
        area.coords = areaJSON.Attr.Coords;
        area.shape = areaJSON.Attr.Shape;
        return area;
    };
    /**
     * @param {?} data
     * @return {?}
     */
    ChoiceDataElementCreationService.prototype.createElement = function (data) {
        var /** @type {?} */ dataElement = new ChoiceDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.allowFreetext = data.Attr.AllowFreetext ? data.Attr.AllowFreetext : false;
        var /** @type {?} */ choiceItems = data.ChoiceInfo.Choice;
        var /** @type {?} */ defaultValue;
        if (choiceItems !== undefined) {
            dataElement.choiceInfo = new Array();
            if (this.arrayCheckerService.isArray(choiceItems)) {
                for (var _a = 0, choiceItems_1 = choiceItems; _a < choiceItems_1.length; _a++) {
                    var choiceItem = choiceItems_1[_a];
                    var /** @type {?} */ choice = this.returnChoice(choiceItem);
                    if (choice.default) {
                        defaultValue = choice.value;
                    }
                    dataElement.choiceInfo.push(choice);
                }
            }
            else {
                var /** @type {?} */ choice = this.returnChoice(choiceItems);
                if (choice.default) {
                    defaultValue = choice.value;
                }
                dataElement.choiceInfo.push(choice);
            }
        }
        dataElement.defaultValue = defaultValue;
        dataElement.currentValue = defaultValue;
        var /** @type {?} */ imageMap = data.ImageMap;
        if (imageMap !== undefined) {
            dataElement.imageMap = new ImageMap();
            dataElement.imageMap.location = imageMap.Location;
            var /** @type {?} */ areaMaps = imageMap.Map.Area;
            if (areaMaps !== undefined) {
                dataElement.imageMap.map = new AreaMap();
                dataElement.imageMap.map.areas = new Array();
                if (this.arrayCheckerService.isArray(areaMaps)) {
                    for (var _b = 0, areaMaps_1 = areaMaps; _b < areaMaps_1.length; _b++) {
                        var areaMap = areaMaps_1[_b];
                        dataElement.imageMap.map.areas.push(this.returnArea(areaMap));
                    }
                }
                else {
                    dataElement.imageMap.map.areas.push(this.returnArea(areaMaps));
                }
            }
        }
        return dataElement;
    };
    return ChoiceDataElementCreationService;
}(DataElementCreationBaseService));
ChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ChoiceDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
]; };
var MultipleChoiceDataElementCreationService = (function (_super) {
    __extends(MultipleChoiceDataElementCreationService, _super);
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    function MultipleChoiceDataElementCreationService(diagramService, arrayCheckerService) {
        var _this = _super.call(this, diagramService, arrayCheckerService) || this;
        _this.elementType = 'MultiChoiceDataElement';
        return _this;
    }
    return MultipleChoiceDataElementCreationService;
}(ChoiceDataElementCreationService));
MultipleChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
MultipleChoiceDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
]; };
var NumericDataElement = (function (_super) {
    __extends(NumericDataElement, _super);
    function NumericDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NumericDataElement;
}(BaseDataElement));
var NumericDataElementCreationService = (function (_super) {
    __extends(NumericDataElementCreationService, _super);
    /**
     * @param {?} diagramService
     */
    function NumericDataElementCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'NumericDataElement';
        return _this;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    NumericDataElementCreationService.prototype.createElement = function (data) {
        var /** @type {?} */ dataElement = new NumericDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    };
    return NumericDataElementCreationService;
}(DataElementCreationBaseService));
NumericDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NumericDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var IntegerDataElement = (function (_super) {
    __extends(IntegerDataElement, _super);
    function IntegerDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return IntegerDataElement;
}(BaseDataElement));
var IntegerDataElementCreationService = (function (_super) {
    __extends(IntegerDataElementCreationService, _super);
    /**
     * @param {?} diagramService
     */
    function IntegerDataElementCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'IntegerDataElement';
        return _this;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    IntegerDataElementCreationService.prototype.createElement = function (data) {
        var /** @type {?} */ dataElement = new IntegerDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    };
    return IntegerDataElementCreationService;
}(DataElementCreationBaseService));
IntegerDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
IntegerDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var $ = require('jquery');
var AssistDataElementComponent = (function () {
    /**
     * @param {?} simulatorEngineService
     */
    function AssistDataElementComponent(simulatorEngineService) {
        this.simulatorEngineService = simulatorEngineService;
        this.Endpoints = [];
        this.returnReportText = new EventEmitter();
        this.returnExecutionHistory = new EventEmitter();
        this.comparisonValues = [];
        this.selectedChoiceValues = [];
        this.executedResultIds = [];
        this.executedResultHistories = [];
        this.inputValues = [];
    }
    /**
     * @return {?}
     */
    AssistDataElementComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.simulatorEngineService.simulatorStateChanged.subscribe(function (message) {
            _this.simulatorState = (message);
            _this.dataElementValues = _this.simulatorEngineService.getAllDataElementValues();
            for (var _a = 0, _b = _this.dataElements; _a < _b.length; _a++) {
                var dataElement = _b[_a];
                if (_this.simulatorState.nonRelevantDataElementIds && _this.simulatorState.nonRelevantDataElementIds.length > 0) {
                    if (_this.simulatorState.nonRelevantDataElementIds.indexOf(dataElement.id) >= 0) {
                        dataElement.isVisible = false;
                    }
                    else {
                        dataElement.isVisible = true;
                    }
                }
                else {
                    dataElement.isVisible = true;
                }
                dataElement.currentValue = (dataElement.currentValue !== undefined) ? dataElement.currentValue : _this.dataElementValues[dataElement.id];
            }
            if (_this.simulatorState.endPointId && _this.simulatorState.endPointId.length > 0) {
                _this.generateReportText(_this.simulatorState.endPointId);
            }
            else {
                _this.returnReportText.emit(undefined);
            }
        });
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    AssistDataElementComponent.prototype.ngOnChanges = function (changes) {
        this.dataElements = this.dataElements.filter(function (x) { return x.displaySequence != null; }).sort(function (DE_1, DE_2) { return DE_1.displaySequence - DE_2.displaySequence; });
        this.executedResultIds = [];
    };
    /**
     * @param {?} $event
     * @return {?}
     */
    AssistDataElementComponent.prototype.choiceSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.selectedChoiceValues[$event.receivedElement.elementId + 'SelectedValue'] = $event.receivedElement.selectedText;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedText);
            var /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    /**
     * @param {?} $event
     * @return {?}
     */
    AssistDataElementComponent.prototype.numericSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedValue);
            var /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    /**
     * @param {?} $event
     * @return {?}
     */
    AssistDataElementComponent.prototype.multiSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.comparisonValues[$event.receivedElement.elementId + 'ComparisonValue'] = $event.receivedElement.selectedComparisonValues;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedComparisonValues, $event.receivedElement.selectedValues);
            var /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    /**
     * @param {?} inputValues
     * @param {?} isReset
     * @return {?}
     */
    AssistDataElementComponent.prototype.load = function (inputValues, isReset) {
        if (inputValues !== undefined) {
            if (isReset) {
                $('select').prop('selectedIndex', 0);
            }
            this.returnReportText.emit(undefined);
            for (var _a = 0, inputValues_1 = inputValues; _a < inputValues_1.length; _a++) {
                var inputValue = inputValues_1[_a];
                if (inputValue !== undefined) {
                    for (var _b = 0, _c = this.dataElements; _b < _c.length; _b++) {
                        var dataElement = _c[_b];
                        if (dataElement.id === inputValue.dataElementId) {
                            switch (dataElement.dataElementType) {
                                case 'ChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', true);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                        }
                                        else {
                                            $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', false);
                                            // $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).trigger('click');
                                            this.isReset = true;
                                        }
                                    }
                                    break;
                                case 'IntegerDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        else {
                                            $('#' + inputValue.dataElementId).val('');
                                            $('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        var /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'NumericDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        else {
                                            $('#' + inputValue.dataElementId).val('');
                                            $('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        var /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'MultiChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        var /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        if (inputValue.dataElementValue.length !== undefined && inputValue.dataElementValue.length > 0) {
                                            if (!isReset) {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (var /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', true);
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', true);
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                            else {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (var /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', false);
                                                        customEvent.initEvent('change', true, true);
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', false);
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                            // if (isReset) {
                                            //   for (const value in inputValue.dataElementValue) {
                                            //     customEvent.initEvent('change', true, true);
                                            //     $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[value])[0].dispatchEvent(customEvent);
                                            //   }
                                            // }
                                        }
                                    }
                                    break;
                            }
                        }
                    }
                }
            }
        }
        else {
            throw console.error('Invalid values');
        }
    };
    /**
     * @param {?} endpointId
     * @return {?}
     */
    AssistDataElementComponent.prototype.generateReportText = function (endpointId) {
        var /** @type {?} */ endpointContent = this.returnEndPointContents(this.xmlContent, '<EndPoint Id="' + endpointId + '">', '</EndPoint>');
        this.parseXml(endpointId, endpointContent);
    };
    /**
     * @return {?}
     */
    AssistDataElementComponent.prototype.generateExecutionHistory = function () {
        this.executedResultHistories = [];
        var /** @type {?} */ isNonRelevant;
        isNonRelevant = false;
        for (var /** @type {?} */ resultId in this.executedResultIds) {
            for (var _a = 0, _b = this.simulatorState.nonRelevantDataElementIds; _a < _b.length; _a++) {
                var nonRelevantDataElement = _b[_a];
                if (nonRelevantDataElement === resultId) {
                    isNonRelevant = true;
                    break;
                }
                else {
                    isNonRelevant = false;
                }
            }
            if (!isNonRelevant) {
                for (var /** @type {?} */ label in this.executedResultIds[resultId]) {
                    var /** @type {?} */ executedResultHistory = new ExecutedResultHistory();
                    executedResultHistory.resultCondition = label;
                    executedResultHistory.resultValue = this.executedResultIds[resultId][label];
                    this.executedResultHistories.push(executedResultHistory);
                }
            }
        }
        var /** @type {?} */ finalExecution = new FinalExecutedHistory();
        if (this.executedResultHistories.length > 0) {
            finalExecution.executionHistories = this.executedResultHistories;
            finalExecution.resultText = this.mainReportTextObj;
        }
        this.returnExecutionHistory.emit(finalExecution);
    };
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    AssistDataElementComponent.prototype.returnEndPointContents = function (content, startToken, endToken) {
        var /** @type {?} */ contents;
        var /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            var /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            var /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                var /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                var /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents = contentData;
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    };
    /**
     * @param {?} endPointId
     * @param {?} endpointContent
     * @return {?}
     */
    AssistDataElementComponent.prototype.parseXml = function (endPointId, endpointContent) {
        var /** @type {?} */ canInsertText;
        var /** @type {?} */ isSectionIf;
        var /** @type {?} */ selectedElements;
        var /** @type {?} */ executeSectionIfNot;
        var /** @type {?} */ hasSectionNot;
        var /** @type {?} */ executeTemplate;
        var /** @type {?} */ isImpression;
        var /** @type {?} */ isNewTemplate;
        var /** @type {?} */ hasInsertPartial;
        var /** @type {?} */ isMainText;
        var /** @type {?} */ allReportText = [];
        var /** @type {?} */ endpoints = this.Endpoints;
        var /** @type {?} */ templatePartialsText;
        var /** @type {?} */ selectedComparisonValues;
        var /** @type {?} */ findingsText;
        var /** @type {?} */ impressionText;
        var /** @type {?} */ selectedSection;
        var /** @type {?} */ selectedChoiceTexts;
        var /** @type {?} */ textExpressionValue;
        selectedElements = this.simulatorEngineService.getAllDataElementValues();
        templatePartialsText = this.templatePartial;
        selectedComparisonValues = this.comparisonValues;
        selectedChoiceTexts = this.simulatorEngineService.getAllDataElementTexts();
        executeSectionIfNot = false;
        hasInsertPartial = false;
        findingsText = '';
        impressionText = '';
        var /** @type {?} */ isReportText;
        var /** @type {?} */ reportTextContent = '';
        var /** @type {?} */ endpointSax = require('sax'), /** @type {?} */ strict = true, /** @type {?} */ normalize = true, /** @type {?} */ // set to false for html-mode
        trim = true, /** @type {?} */ reportTextParser = endpointSax.parser(strict, trim);
        reportTextParser.onerror = function (e) {
            // an error happened.
            reportTextParser.resume();
        };
        reportTextParser.ontext = function (t) {
            if (t.length > 1) {
                t = t.trim();
            }
            var /** @type {?} */ isTextInserted;
            isTextInserted = false;
            if (executeTemplate) {
                if (!isImpression) {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && isNewTemplate && hasInsertPartial && !isSectionIf) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && !isImpression) {
                        findingsText = findingsText + t;
                    }
                }
                else {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && !hasSectionNot && isImpression) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && isNewTemplate) {
                        impressionText = impressionText + t;
                    }
                }
                if (isReportText && !isTextInserted && isMainText && canInsertText) {
                    reportTextContent = reportTextContent + t;
                }
            }
        };
        reportTextParser.onopentag = function (node) {
            switch (node.name) {
                case 'Label':
                    canInsertText = false;
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'ReportText':
                    if (executeTemplate) {
                        isReportText = true;
                        canInsertText = true;
                        selectedSection = node.attributes.SectionId;
                        impressionText = '';
                        if (node.attributes.SectionId === 'findings' && executeTemplate) {
                            isImpression = false;
                        }
                        else if (node.attributes.SectionId === 'impression' && executeTemplate) {
                            isImpression = true;
                        }
                    }
                    isSectionIf = false;
                    // isMainText = true;
                    break;
                case 'InsertPartial':
                    if (executeTemplate) {
                        generatePartialView(node.attributes.PartialId, isImpression);
                        executeTemplate = true;
                        canInsertText = true;
                        if (isReportText) {
                            hasInsertPartial = true;
                        }
                        else {
                            hasInsertPartial = false;
                        }
                    }
                    else {
                        canInsertText = false;
                    }
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'SectionIfValueNot':
                    if (executeTemplate) {
                        if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                            for (var _a = 0, _b = selectedElements[node.attributes.DataElementId]; _a < _b.length; _a++) {
                                var comaprisonValue = _b[_a];
                                if (comaprisonValue !== node.attributes.ComparisonValue &&
                                    comaprisonValue !== undefined && !isSectionIf) {
                                    canInsertText = true;
                                    executeSectionIfNot = true;
                                    break;
                                }
                                else {
                                    canInsertText = false;
                                    executeSectionIfNot = false;
                                }
                            }
                        }
                        else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                            selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                            selectedElements[node.attributes.DataElementId] !== undefined &&
                            selectedElements[node.attributes.DataElementId] !== null) {
                            canInsertText = true;
                            executeSectionIfNot = true;
                        }
                        else {
                            canInsertText = false;
                            executeSectionIfNot = false;
                        }
                    }
                    hasSectionNot = true;
                    isMainText = false;
                    break;
                case 'SectionIf':
                    if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                        isSectionIf = true;
                        canInsertText = true;
                    }
                    else {
                        isSectionIf = false;
                        canInsertText = false;
                    }
                    break;
                case 'SectionIfValue':
                    if (executeTemplate) {
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (var _c = 0, _d = selectedElements[node.attributes.DataElementId]; _c < _d.length; _c++) {
                                    var comaprisonValue = _d[_c];
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    }
                    isMainText = false;
                    break;
                case 'InsertValue':
                    if (executeTemplate) {
                        isReportText = false;
                        var /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                        if (node.attributes.Id === 'findings' || canInsertText) {
                            if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            if (isImpression) {
                                canInsertText = true;
                            }
                        }
                        isMainText = false;
                        break;
                    }
            }
            executeTemplate = true;
            isNewTemplate = true;
        };
        reportTextParser.onclosetag = function (node) {
            switch (node) {
                case 'SectionIfValueNot':
                    executeSectionIfNot = false;
                    hasSectionNot = false;
                    if (isSectionIf) {
                        canInsertText = true;
                    }
                    break;
                case 'TemplatePartial':
                    isNewTemplate = false;
                    canInsertText = false;
                    executeTemplate = false;
                    break;
                case 'ReportText':
                    // isImpression = false;
                    if (!hasInsertPartial && !isImpression) {
                        var /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = 'findings';
                        reportTextObj.reportText = findingsText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    if (impressionText !== '' && impressionText !== undefined) {
                        var /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = selectedSection;
                        reportTextObj.reportText = impressionText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    hasInsertPartial = false;
                    break;
                case 'SectionIf':
                    isSectionIf = false;
                    canInsertText = true;
                    break;
                case 'InsertPartial':
                    canInsertText = true;
                    break;
                case 'InsertValue':
                    if ((hasSectionNot && executeSectionIfNot || !hasSectionNot)) {
                        canInsertText = true;
                    }
                    break;
                case 'SectionIfValue':
                    canInsertText = true;
                    break;
            }
        };
        reportTextParser.onend = function () {
            // parser stream is done, and ready to have more stuff written to it.
            // if (impressionText !== '' && impressionText !== undefined) {
            // const reportTextObj: AllReportText = new AllReportText();
            // reportTextObj.sectionId = selectedSection;
            // reportTextObj.reportText = impressionText;
            // allReportText[reportTextObj.sectionId] = reportTextObj;
            // }
        };
        reportTextParser.write(endpointContent).onend();
        /**
         * @param {?} textExpression
         * @return {?}
         */
        function getTextExpressionValue(textExpression) {
            if (textExpression.indexOf('{') === 0 && (textExpression.indexOf('}') > 1)) {
                var /** @type {?} */ subString = textExpression.substr(textExpression.indexOf('{') + 1, textExpression.indexOf('}') - 1);
                getTextExpressionValue(selectedElements[subString]);
            }
            else {
                textExpressionValue = textExpression;
            }
        }
        /**
         * @param {?} partialViewId
         * @param {?} isImpressionTemplate
         * @return {?}
         */
        function generatePartialView(partialViewId, isImpressionTemplate) {
            // this.templateIds = [];
            var /** @type {?} */ sax = require('sax'), /** @type {?} */ parser = sax.parser(strict, trim);
            parser.onerror = function (e) {
                // an error happened.
                // parser.resume();
            };
            parser.ontext = function (t) {
                if (executeTemplate) {
                    if (!isImpressionTemplate) {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            findingsText = findingsText + t;
                        }
                    }
                    else {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            impressionText = impressionText + t;
                        }
                    }
                }
            };
            parser.onopentag = function (node) {
                switch (node.name) {
                    case 'Label':
                        canInsertText = false;
                        break;
                    case 'EndPoint':
                        if (node.attributes.Id !== '') {
                            canInsertText = true;
                            isImpression = true;
                        }
                        else {
                            canInsertText = false;
                            isImpression = false;
                        }
                        break;
                    case 'InsertPartial':
                        canInsertText = false;
                        break;
                    case 'ReportText':
                        canInsertText = true;
                        break;
                    case 'TemplatePartial':
                        hasSectionNot = false;
                        executeSectionIfNot = false;
                        if (node.attributes.Id === partialViewId) {
                            executeTemplate = true;
                            canInsertText = true;
                            isNewTemplate = true;
                            break;
                        }
                        else {
                            isNewTemplate = false;
                            executeTemplate = false;
                        }
                        break;
                    case 'SectionIfValueNot':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (var _a = 0, _b = selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']; _a < _b.length; _a++) {
                                    var comaprisonValue = _b[_a];
                                    if (comaprisonValue !== node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined && !isSectionIf) {
                                        canInsertText = true;
                                        executeSectionIfNot = true;
                                        break;
                                    }
                                    else {
                                        canInsertText = false;
                                        executeSectionIfNot = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                                selectedElements[node.attributes.DataElementId] !== undefined &&
                                selectedElements[node.attributes.DataElementId] !== null) {
                                canInsertText = true;
                                executeSectionIfNot = true;
                            }
                            else {
                                canInsertText = false;
                                executeSectionIfNot = false;
                            }
                        }
                        hasSectionNot = true;
                        break;
                    case 'SectionIf':
                        if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && (!hasSectionNot || (hasSectionNot && executeSectionIfNot))
                            && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                            isSectionIf = true;
                            canInsertText = true;
                        }
                        else {
                            isSectionIf = false;
                            canInsertText = false;
                        }
                        break;
                    case 'SectionIfValue':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (var _c = 0, _d = selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']; _c < _d.length; _c++) {
                                    var comaprisonValue = _d[_c];
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    case 'InsertValue':
                        if (executeTemplate) {
                            var /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                            if (node.attributes.Id === 'findings' || canInsertText) {
                                if (isImpression) {
                                    canInsertText = true;
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                            }
                                        }
                                    }
                                }
                                else {
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                }
                            }
                            break;
                        }
                }
            };
            parser.onclosetag = function (node) {
                switch (node) {
                    case 'SectionIfValueNot':
                        executeSectionIfNot = false;
                        hasSectionNot = false;
                        if (isSectionIf) {
                            canInsertText = true;
                        }
                        break;
                    case 'TemplatePartial':
                        isNewTemplate = true;
                        canInsertText = false;
                        executeTemplate = true;
                        break;
                    case 'InsertPartial':
                        canInsertText = true;
                        break;
                    case 'SectionIf' || 'SectionIfValue':
                        isSectionIf = false;
                        break;
                }
            };
            parser.onend = function () {
                // parser stream is done, and ready to have more stuff written to it.
                var /** @type {?} */ reportTextObj = new AllReportText();
                reportTextObj.sectionId = 'findings';
                reportTextObj.reportText = findingsText;
                allReportText[reportTextObj.sectionId] = reportTextObj;
            };
            parser.write(templatePartialsText).onend();
        }
        this.mainReportTextObj = new MainReportText();
        this.mainReportTextObj.reportTextMainContent = reportTextContent;
        this.mainReportTextObj.allReportText = allReportText;
        this.returnReportText.emit(this.mainReportTextObj);
    };
    return AssistDataElementComponent;
}());
AssistDataElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-data-element',
                template: "\n    <ng-container *ngFor=\"let DataElement of dataElements\">\n        <ng-container *ngIf=\"(DataElement.dataElementType == 'ChoiceDataElement' || DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement' || DataElement.dataElementType == 'MultiChoiceDataElement') \">\n            <ng-container *ngIf=\"DataElement.isVisible\">\n                <div id=\"div_{{DataElement.id}}\" class=\"row bottom-margin\"> \n                    <ng-container *ngIf=\"DataElement.dataElementType == 'ChoiceDataElement'\">\n                        <acr-assist-choice-element [choiceDataElement]='DataElement' [imagePath]='imagePath' (returnChoiceElement)='choiceSelected($event)'></acr-assist-choice-element>\n                    </ng-container>          \n    \n                    <ng-container *ngIf=\"DataElement.dataElementType == 'MultiChoiceDataElement'\">\n                        <acr-assist-multi-choice-element [multiChoiceElement]='DataElement' [imagePath]='imagePath'  (returnMultiChoice)='multiSelected($event)'></acr-assist-multi-choice-element>\n                    </ng-container>\n    \n                    <ng-container *ngIf=\"DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement'\">\n                        <acr-assist-numeric-element [numericDataElement]='DataElement' [imagePath]='imagePath' (returnNumericElement)='numericSelected($event)'></acr-assist-numeric-element>\n                    </ng-container>\n                </div>  \n            </ng-container>        \n        </ng-container>\n    </ng-container>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AssistDataElementComponent.ctorParameters = function () { return [
    { type: SimulatorEngineService, },
]; };
AssistDataElementComponent.propDecorators = {
    'dataElements': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'Endpoints': [{ type: Input },],
    'templatePartial': [{ type: Input },],
    'endPointXMLString': [{ type: Input },],
    'xmlContent': [{ type: Input },],
    'returnReportText': [{ type: Output },],
    'returnExecutionHistory': [{ type: Output },],
    'isReset': [{ type: Input },],
    'inputValues': [{ type: Input },],
};
var ChoiceElement = (function () {
    function ChoiceElement() {
    }
    return ChoiceElement;
}());
var NumericElement = (function () {
    function NumericElement() {
    }
    return NumericElement;
}());
var MultiChoiceElement = (function () {
    function MultiChoiceElement() {
    }
    return MultiChoiceElement;
}());
var MainReportText = (function () {
    function MainReportText() {
    }
    return MainReportText;
}());
var AllReportText = (function () {
    function AllReportText() {
    }
    return AllReportText;
}());
var ExecutedResultHistory = (function () {
    function ExecutedResultHistory() {
    }
    return ExecutedResultHistory;
}());
var FinalExecutedHistory = (function () {
    function FinalExecutedHistory() {
    }
    return FinalExecutedHistory;
}());
var HintDiagramComponent = (function () {
    function HintDiagramComponent() {
        this.activeSlideIndex = 0;
    }
    /**
     * @return {?}
     */
    HintDiagramComponent.prototype.resetCarouselIndex = function () {
        this.activeSlideIndex = 0;
    };
    return HintDiagramComponent;
}());
HintDiagramComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-hint-diagram',
                template: "\n    <ng-container *ngIf=\"DataElement !== undefined\">\n\n\n\n    <button type=\"button\" class=\"btn btn-default btn-xs\" data-toggle=\"modal\" attr.data-target=\"#{{'diag_'+DataElement.id}}\" (click)=\"resetCarouselIndex()\">\n      <span class=\" glyphicon glyphicon-cd\" aria-hidden=\"true\" data-toggle=\"tooltip\"  data-placement=\"right\" title=\"Hint Diagrams\"></span>\n\n    </button>\n    <div class=\"modal fade adjust-diagram \" tabindex=\"-1\" role=\"dialog\" attr.id=\"{{'diag_'+DataElement.id}}\" aria-labelledby=\"mySmallModalLabel\">\n        <div class=\"modal-dialog modal-lg adjust-diagram-image \" role=\"document\">\n            <div class=\"modal-content\">\n                <div class=\"modal-header\">\n                    <h4 class=\"modal-title\">\n                        {{DataElement.label}}\n                    </h4>\n                    <button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\"><span aria-hidden=\"true\">\u00D7</span></button>\n                </div>\n                <ng-container>\n                    <carousel [(activeSlide)]=\"activeSlideIndex\" interval=\"false\">\n                        <ng-container *ngFor=\"let diag of DataElement.diagrams \">\n                            <slide>\n                                <img  src=\"{{imagePath}}/{{diag.location}}\" alt=\"Image Not Available!!!\">\n                            </slide>\n                        </ng-container>  \n                    </carousel>\n                </ng-container>\n            </div>\n        </div>\n    </div>\n    </ng-container>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
HintDiagramComponent.ctorParameters = function () { return []; };
HintDiagramComponent.propDecorators = {
    'DataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
};
/*tslint:disable:no-invalid-this */
var LinkedList = (function () {
    function LinkedList() {
        this.length = 0;
        this.asArray = [];
    }
    LinkedList.prototype.getNode = function (position) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        var current = this.head;
        for (var index = 0; index < position; index++) {
            current = current.next;
        }
        return current;
    };
    LinkedList.prototype.createInternalArrayRepresentation = function () {
        var outArray = [];
        var current = this.head;
        while (current) {
            outArray.push(current.value);
            current = current.next;
        }
        this.asArray = outArray;
    };
    LinkedList.prototype.get = function (position) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            return void 0;
        }
        var current = this.head;
        for (var index = 0; index < position; index++) {
            current = current.next;
        }
        return current.value;
    };
    LinkedList.prototype.add = function (value, position) {
        if (position === void 0) {
            position = this.length;
        }
        if (position < 0 || position > this.length) {
            throw new Error('Position is out of the list');
        }
        var node = {
            value: value,
            next: undefined,
            previous: undefined
        };
        if (this.length === 0) {
            this.head = node;
            this.tail = node;
            this.current = node;
        }
        else {
            if (position === 0) {
                // first node
                node.next = this.head;
                this.head.previous = node;
                this.head = node;
            }
            else if (position === this.length) {
                // last node
                this.tail.next = node;
                node.previous = this.tail;
                this.tail = node;
            }
            else {
                // node in middle
                var currentPreviousNode = this.getNode(position - 1);
                var currentNextNode = currentPreviousNode.next;
                currentPreviousNode.next = node;
                currentNextNode.previous = node;
                node.previous = currentPreviousNode;
                node.next = currentNextNode;
            }
        }
        this.length++;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.remove = function (position) {
        if (position === void 0) {
            position = 0;
        }
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        if (position === 0) {
            // first node
            this.head = this.head.next;
            if (this.head) {
                // there is no second node
                this.head.previous = undefined;
            }
            else {
                // there is no second node
                this.tail = undefined;
            }
        }
        else if (position === this.length - 1) {
            // last node
            this.tail = this.tail.previous;
            this.tail.next = undefined;
        }
        else {
            // middle node
            var removedNode = this.getNode(position);
            removedNode.next.previous = removedNode.previous;
            removedNode.previous.next = removedNode.next;
        }
        this.length--;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.set = function (position, value) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        var node = this.getNode(position);
        node.value = value;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.toArray = function () {
        return this.asArray;
    };
    LinkedList.prototype.findAll = function (fn) {
        var current = this.head;
        var result = [];
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result.push({ index: index, value: current.value });
            }
            current = current.next;
        }
        return result;
    };
    // Array methods overriding start
    LinkedList.prototype.push = function () {
        var _this = this;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        args.forEach(function (arg) {
            _this.add(arg);
        });
        return this.length;
    };
    LinkedList.prototype.pop = function () {
        if (this.length === 0) {
            return undefined;
        }
        var last = this.tail;
        this.remove(this.length - 1);
        return last.value;
    };
    LinkedList.prototype.unshift = function () {
        var _this = this;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        args.reverse();
        args.forEach(function (arg) {
            _this.add(arg, 0);
        });
        return this.length;
    };
    LinkedList.prototype.shift = function () {
        if (this.length === 0) {
            return undefined;
        }
        var lastItem = this.head.value;
        this.remove();
        return lastItem;
    };
    LinkedList.prototype.forEach = function (fn) {
        var current = this.head;
        for (var index = 0; index < this.length; index++) {
            fn(current.value, index);
            current = current.next;
        }
    };
    LinkedList.prototype.indexOf = function (value) {
        var current = this.head;
        var position = 0;
        for (var index = 0; index < this.length; index++) {
            if (current.value === value) {
                position = index;
                break;
            }
            current = current.next;
        }
        return position;
    };
    LinkedList.prototype.some = function (fn) {
        var current = this.head;
        var result = false;
        while (current && !result) {
            if (fn(current.value)) {
                result = true;
                break;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.every = function (fn) {
        var current = this.head;
        var result = true;
        while (current && result) {
            if (!fn(current.value)) {
                result = false;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.toString = function () {
        return '[Linked List]';
    };
    LinkedList.prototype.find = function (fn) {
        var current = this.head;
        var result;
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result = current.value;
                break;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.findIndex = function (fn) {
        var current = this.head;
        var result;
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result = index;
                break;
            }
            current = current.next;
        }
        return result;
    };
    return LinkedList;
}());
/*tslint:disable */
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * JS version of browser APIs. This library can only run in the browser.
 */
var win = typeof window !== 'undefined' && window || {};
var document$1 = win.document;
var location = win.location;
var gc = win['gc'] ? function () { return win['gc'](); } : function () { return null; };
var performance = win['performance'] ? win['performance'] : null;
var Event = win['Event'];
var MouseEvent = win['MouseEvent'];
var KeyboardEvent = win['KeyboardEvent'];
var EventTarget = win['EventTarget'];
var History = win['History'];
var Location = win['Location'];
var EventListener = win['EventListener'];
function isBs3() {
    return win.__theme !== 'bs4';
}
/**
 * @copyright Valor Software
 * @copyright Angular ng-bootstrap team
 */
var CarouselConfig = (function () {
    function CarouselConfig() {
        /** Default interval of auto changing of slides */
        this.interval = 5000;
        /** Is loop of auto changing of slides can be paused */
        this.noPause = false;
        /** Is slides can wrap from the last to the first slide */
        this.noWrap = false;
    }
    CarouselConfig.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    CarouselConfig.ctorParameters = function () { return []; };
    return CarouselConfig;
}());
// todo: add animation
var Direction;
(function (Direction) {
    Direction[Direction["UNKNOWN"] = 0] = "UNKNOWN";
    Direction[Direction["NEXT"] = 1] = "NEXT";
    Direction[Direction["PREV"] = 2] = "PREV";
})(Direction || (Direction = {}));
/**
 * Base element to create carousel
 */
var CarouselComponent = (function () {
    function CarouselComponent(config) {
        /** Will be emitted when active slide has been changed. Part of two-way-bindable [(activeSlide)] property */
        this.activeSlideChange = new EventEmitter(false);
        this._slides = new LinkedList();
        this.destroyed = false;
        Object.assign(this, config);
    }
    Object.defineProperty(CarouselComponent.prototype, "activeSlide", {
        get: function () {
            return this._currentActiveSlide;
        },
        /** Index of currently displayed slide(started for 0) */
        set: function (index) {
            if (this._slides.length && index !== this._currentActiveSlide) {
                this._select(index);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "interval", {
        /**
         * Delay of item cycling in milliseconds. If false, carousel won't cycle automatically.
         */
        get: function () {
            return this._interval;
        },
        set: function (value) {
            this._interval = value;
            this.restartTimer();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "slides", {
        get: function () {
            return this._slides.toArray();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "isBs4", {
        get: function () {
            return !isBs3();
        },
        enumerable: true,
        configurable: true
    });
    CarouselComponent.prototype.ngOnDestroy = function () {
        this.destroyed = true;
    };
    /**
     * Adds new slide. If this slide is first in collection - set it as active and starts auto changing
     * @param slide
     */
    CarouselComponent.prototype.addSlide = function (slide) {
        this._slides.add(slide);
        if (this._slides.length === 1) {
            this._currentActiveSlide = void 0;
            this.activeSlide = 0;
            this.play();
        }
    };
    /**
     * Removes specified slide. If this slide is active - will roll to another slide
     * @param slide
     */
    CarouselComponent.prototype.removeSlide = function (slide) {
        var _this = this;
        var remIndex = this._slides.indexOf(slide);
        if (this._currentActiveSlide === remIndex) {
            // removing of active slide
            var nextSlideIndex_1 = void 0;
            if (this._slides.length > 1) {
                // if this slide last - will roll to first slide, if noWrap flag is FALSE or to previous, if noWrap is TRUE
                // in case, if this slide in middle of collection, index of next slide is same to removed
                nextSlideIndex_1 = !this.isLast(remIndex) ? remIndex :
                    this.noWrap ? remIndex - 1 : 0;
            }
            this._slides.remove(remIndex);
            // prevents exception with changing some value after checking
            setTimeout(function () {
                _this._select(nextSlideIndex_1);
            }, 0);
        }
        else {
            this._slides.remove(remIndex);
            var currentSlideIndex_1 = this.getCurrentSlideIndex();
            setTimeout(function () {
                // after removing, need to actualize index of current active slide
                _this._currentActiveSlide = currentSlideIndex_1;
                _this.activeSlideChange.emit(_this._currentActiveSlide);
            }, 0);
        }
    };
    /**
     * Rolling to next slide
     * @param force: {boolean} if true - will ignore noWrap flag
     */
    CarouselComponent.prototype.nextSlide = function (force) {
        if (force === void 0) {
            force = false;
        }
        this.activeSlide = this.findNextSlideIndex(Direction.NEXT, force);
    };
    /**
     * Rolling to previous slide
     * @param force: {boolean} if true - will ignore noWrap flag
     */
    CarouselComponent.prototype.previousSlide = function (force) {
        if (force === void 0) {
            force = false;
        }
        this.activeSlide = this.findNextSlideIndex(Direction.PREV, force);
    };
    /**
     * Rolling to specified slide
     * @param index: {number} index of slide, which must be shown
     */
    CarouselComponent.prototype.selectSlide = function (index) {
        this.activeSlide = index;
    };
    /**
     * Starts a auto changing of slides
     */
    CarouselComponent.prototype.play = function () {
        if (!this.isPlaying) {
            this.isPlaying = true;
            this.restartTimer();
        }
    };
    /**
     * Stops a auto changing of slides
     */
    CarouselComponent.prototype.pause = function () {
        if (!this.noPause) {
            this.isPlaying = false;
            this.resetTimer();
        }
    };
    /**
     * Finds and returns index of currently displayed slide
     * @returns {number}
     */
    CarouselComponent.prototype.getCurrentSlideIndex = function () {
        return this._slides.findIndex(function (slide) { return slide.active; });
    };
    /**
     * Defines, whether the specified index is last in collection
     * @param index
     * @returns {boolean}
     */
    CarouselComponent.prototype.isLast = function (index) {
        return index + 1 >= this._slides.length;
    };
    /**
     * Defines next slide index, depending of direction
     * @param direction: Direction(UNKNOWN|PREV|NEXT)
     * @param force: {boolean} if TRUE - will ignore noWrap flag, else will return undefined if next slide require wrapping
     * @returns {any}
     */
    CarouselComponent.prototype.findNextSlideIndex = function (direction, force) {
        var nextSlideIndex = 0;
        if (!force && (this.isLast(this.activeSlide) && direction !== Direction.PREV && this.noWrap)) {
            return void 0;
        }
        switch (direction) {
            case Direction.NEXT:
                // if this is last slide, not force, looping is disabled and need to going forward - select current slide, as a next
                nextSlideIndex = (!this.isLast(this._currentActiveSlide)) ? this._currentActiveSlide + 1 :
                    (!force && this.noWrap) ? this._currentActiveSlide : 0;
                break;
            case Direction.PREV:
                // if this is first slide, not force, looping is disabled and need to going backward - select current slide, as a next
                nextSlideIndex = (this._currentActiveSlide > 0) ? this._currentActiveSlide - 1 :
                    (!force && this.noWrap) ? this._currentActiveSlide : this._slides.length - 1;
                break;
            default:
                throw new Error('Unknown direction');
        }
        return nextSlideIndex;
    };
    /**
     * Sets a slide, which specified through index, as active
     * @param index
     * @private
     */
    CarouselComponent.prototype._select = function (index) {
        if (isNaN(index)) {
            this.pause();
            return;
        }
        var currentSlide = this._slides.get(this._currentActiveSlide);
        if (currentSlide) {
            currentSlide.active = false;
        }
        var nextSlide = this._slides.get(index);
        if (nextSlide) {
            this._currentActiveSlide = index;
            nextSlide.active = true;
            this.activeSlide = index;
            this.activeSlideChange.emit(index);
        }
    };
    /**
     * Starts loop of auto changing of slides
     */
    CarouselComponent.prototype.restartTimer = function () {
        var _this = this;
        this.resetTimer();
        var interval = +this.interval;
        if (!isNaN(interval) && interval > 0) {
            this.currentInterval = setInterval(function () {
                var nInterval = +_this.interval;
                if (_this.isPlaying && !isNaN(_this.interval) && nInterval > 0 && _this.slides.length) {
                    _this.nextSlide();
                }
                else {
                    _this.pause();
                }
            }, interval);
        }
    };
    /**
     * Stops loop of auto changing of slides
     */
    CarouselComponent.prototype.resetTimer = function () {
        if (this.currentInterval) {
            clearInterval(this.currentInterval);
            this.currentInterval = void 0;
        }
    };
    CarouselComponent.decorators = [
        { type: Component, args: [{
                    selector: 'carousel',
                    template: "\n    <div (mouseenter)=\"pause()\" (mouseleave)=\"play()\" (mouseup)=\"play()\" class=\"carousel slide\">\n      <ol class=\"carousel-indicators\" *ngIf=\"slides.length > 1\">\n         <li *ngFor=\"let slidez of slides; let i = index;\" [class.active]=\"slidez.active === true\" (click)=\"selectSlide(i)\"></li>\n      </ol>\n      <div class=\"carousel-inner\"><ng-content></ng-content></div>\n      <a class=\"left carousel-control carousel-control-prev\" [class.disabled]=\"activeSlide === 0 && noWrap\" (click)=\"previousSlide()\" *ngIf=\"slides.length > 1\">\n        <span class=\"icon-prev carousel-control-prev-icon\" aria-hidden=\"true\"></span>\n        <span *ngIf=\"isBs4\" class=\"sr-only\">Previous</span>\n      </a>\n      <a class=\"right carousel-control carousel-control-next\" (click)=\"nextSlide()\"  [class.disabled]=\"isLast(activeSlide) && noWrap\" *ngIf=\"slides.length > 1\">\n        <span class=\"icon-next carousel-control-next-icon\" aria-hidden=\"true\"></span>\n        <span class=\"sr-only\">Next</span>\n      </a>\n    </div>\n  "
                },] },
    ];
    /** @nocollapse */
    CarouselComponent.ctorParameters = function () {
        return [
            { type: CarouselConfig, },
        ];
    };
    CarouselComponent.propDecorators = {
        'noWrap': [{ type: Input },],
        'noPause': [{ type: Input },],
        'activeSlideChange': [{ type: Output },],
        'activeSlide': [{ type: Input },],
        'interval': [{ type: Input },],
    };
    return CarouselComponent;
}());
var SlideComponent = (function () {
    function SlideComponent(carousel) {
        /** Wraps element by appropriate CSS classes */
        this.addClass = true;
        this.carousel = carousel;
    }
    /** Fires changes in container collection after adding a new slide instance */
    SlideComponent.prototype.ngOnInit = function () {
        this.carousel.addSlide(this);
    };
    /** Fires changes in container collection after removing of this slide instance */
    SlideComponent.prototype.ngOnDestroy = function () {
        this.carousel.removeSlide(this);
    };
    SlideComponent.decorators = [
        { type: Component, args: [{
                    selector: 'slide',
                    template: "\n    <div [class.active]=\"active\" class=\"item\">\n      <ng-content></ng-content>\n    </div>\n  "
                },] },
    ];
    /** @nocollapse */
    SlideComponent.ctorParameters = function () {
        return [
            { type: CarouselComponent, },
        ];
    };
    SlideComponent.propDecorators = {
        'active': [{ type: HostBinding, args: ['class.active',] }, { type: Input },],
        'addClass': [{ type: HostBinding, args: ['class.item',] }, { type: HostBinding, args: ['class.carousel-item',] },],
    };
    return SlideComponent;
}());
var GlobalValue = (function (_super) {
    __extends(GlobalValue, _super);
    function GlobalValue() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GlobalValue;
}(BaseDataElement));
var GlobalValueCreationService = (function (_super) {
    __extends(GlobalValueCreationService, _super);
    /**
     * @param {?} diagramService
     */
    function GlobalValueCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'GlobalValue';
        return _this;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    GlobalValueCreationService.prototype.createElement = function (data) {
        var /** @type {?} */ dataElement = new GlobalValue();
        dataElement.id = data.Attr.Id;
        dataElement.currentValue = data._;
        dataElement.dataElementType = 'GlobalValue';
        return dataElement;
    };
    return GlobalValueCreationService;
}(DataElementCreationBaseService));
GlobalValueCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
GlobalValueCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var SelectedCondition = (function () {
    function SelectedCondition() {
    }
    return SelectedCondition;
}());
var $$1 = require('jquery');
var AssistNumericElementComponent = (function () {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    function AssistNumericElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnNumericElement = new EventEmitter();
    }
    /**
     * @return {?}
     */
    AssistNumericElementComponent.prototype.ngOnInit = function () {
        this.createNumericElementForm();
    };
    /**
     * @return {?}
     */
    AssistNumericElementComponent.prototype.ngAfterViewInit = function () {
        if (this.numericDataElement.currentValue !== undefined && this.numericDataElement.currentValue !== 0) {
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            var /** @type {?} */ customEvent = document.createEvent('Event');
            // customEvent.initEvent('change', true, true);
            // $('#' + this.numericDataElement.id)[0].dispatchEvent(customEvent);
            this.numberValue = this.numericDataElement.currentValue;
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            this.loadedNumericValue(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.label);
        }
    };
    /**
     * @param {?} id
     * @param {?} value
     * @param {?} selectedCondition
     * @return {?}
     */
    AssistNumericElementComponent.prototype.loadedNumericValue = function (id, value, selectedCondition) {
        var /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = id;
        choiceElement.selectedValue = value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    AssistNumericElementComponent.prototype.choiceSelected = function (element, selectedCondition) {
        var /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    /**
     * @return {?}
     */
    AssistNumericElementComponent.prototype.createNumericElementForm = function () {
        this.numericElementForm = this.formBuilder.group({
            numericElement: ['', Validators.compose([Validators.required, Validators.min(+this.numericDataElement.minimum)])],
        });
    };
    /**
     * @param {?} numericKey
     * @return {?}
     */
    AssistNumericElementComponent.prototype.specificValueInsideRange = function (numericKey) {
        var _this = this;
        return function (group) {
            var /** @type {?} */ numericControl = group.controls[numericKey];
            if ((numericControl.value === 'undefined' || numericControl.value === '') && _this.numericDataElement.isRequired) {
                return numericControl.setErrors({ notEquivalent: true });
            }
            else {
                return numericControl.setErrors(null);
            }
        };
    };
    /**
     * @param {?} event
     * @return {?}
     */
    AssistNumericElementComponent.prototype.onlyNumberKey = function (event) {
        return (event.charCode === 8 || event.charCode === 0) ? null : event.charCode >= 48 && event.charCode <= 57;
    };
    return AssistNumericElementComponent;
}());
AssistNumericElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-numeric-element',
                template: "\n    <form [formGroup]=\"numericElementForm\" novalidate>\n      <div class=\"col-xs-4 col-sm-6 text-left content-padding\">\n        <label class=\"control-label DEElement\">\n          {{numericDataElement.label}}\n        </label>\n        <ng-container *ngIf=\"numericDataElement.hint !== '' && numericDataElement.hint !== undefined\">\n          <a>\n            <span class=\"glyphicon glyphicon-info-sign\" data-toggle=\"tooltip\" data-placement=\"right\" title=\"{{numericDataElement.hint}}\"></span>\n          </a>\n        </ng-container>\n        <ng-container *ngIf=\"numericDataElement.diagrams != undefined \">\n          <acr-hint-diagram [DataElement]=\"numericDataElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n        </ng-container>\n\n        <ng-container *ngIf=\"this.numericDataElement.isRequired\">\n          <div *ngIf=\"numericElementForm.controls['numericElement'].invalid\" class=\"numeric-align\">\n            <div *ngIf=\"numericElementForm.controls['numericElement'].errors.required\" class=\"required-field\" title=\"Required Field\">\n              *\n            </div>\n          </div>\n        </ng-container>\n        <div *ngIf=\"numericElementForm.controls['numericElement'].invalid && numericElementForm.controls['numericElement'].errors.min\" class=\"required-field numeric-validator\"\n        title=\" Minimum value is {{numericDataElement.minimum}}\">\n            *\n          </div>\n      </div>\n      <ng-container *ngIf=\"numericDataElement.dataElementType === 'NumericDataElement'\">\n        <div class=\"col-xs-8 col-sm-6 text-left content-padding\">\n            <div class=\"row\">\n                <div class=\"col-sm-12\">\n                  <input [(ngModel)]=\"numberValue\" id=\"{{numericDataElement.id}}\" type=\"number\" class=\"form-control\" formControlName=\"numericElement\" (keypress)=\"onlyNumberKey($event)\"\n                  onpaste=\"return false;\" (input)=\"choiceSelected($event.target, numericDataElement.label)\" min=\"{{numericDataElement.minimum}}\" required>\n                </div>\n              </div>\n        </div>\n      </ng-container>\n\n      <ng-container *ngIf=\"numericDataElement.dataElementType === 'IntegerDataElement'\">\n        <div class=\"col-xs-8 col-sm-6 text-left content-padding\">\n          <div class=\"row\">\n              <div class=\"col-sm-12\">\n                <input [(ngModel)]=\"numberValue\" id=\"{{numericDataElement.id}}\" type=\"number\" class=\"form-control\" formControlName=\"numericElement\" (keypress)=\"onlyNumberKey($event)\"\n                onpaste=\"return false;\" (input)=\"choiceSelected($event.target, numericDataElement.label)\" min=\"{{numericDataElement.minimum}}\"  required>\n              </div>\n            </div>\n        </div>\n      </ng-container>\n    </form>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AssistNumericElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistNumericElementComponent.propDecorators = {
    'numericDataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnNumericElement': [{ type: Output },],
};
var $$2 = require('jquery');
var AssistChoiceElementComponent = (function () {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    function AssistChoiceElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnChoiceElement = new EventEmitter();
        this.choiceChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.ngOnInit = function () {
        this.createChoiceElementForm();
    };
    /**
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.ngAfterViewInit = function () {
        if (this.choiceDataElement.currentValue !== undefined) {
            $$2('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id).prop('checked', true);
            this.choiceValue = this.choiceDataElement.currentValue;
            for (var /** @type {?} */ choice in this.choiceDataElement.choiceInfo) {
                if (this.choiceDataElement.choiceInfo[choice].value === this.choiceDataElement.currentValue) {
                    this.simulatorEngineService.addOrUpdateDataElement(this.choiceDataElement.id, this.choiceDataElement.currentValue, this.choiceDataElement.choiceInfo[choice].label);
                }
            }
            var /** @type {?} */ customEvent = document.createEvent('Event');
            customEvent.initEvent('change', true, true);
            if (this.choiceDataElement.choiceInfo.length <= 5) {
                $$2('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id)[0].dispatchEvent(customEvent);
            }
            else {
                $$2('#' + this.choiceDataElement.id).val(this.choiceDataElement.currentValue);
                $$2('#' + this.choiceDataElement.id)[0].dispatchEvent(customEvent);
            }
        }
        $$2('#div_' + this.choiceDataElement.id + '_other').hide();
    };
    /**
     * @param {?} elementId
     * @param {?} selectedElement
     * @param {?} selectedText
     * @param {?} selectedValue
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.choiceSelected = function (elementId, selectedElement, selectedText, selectedValue) {
        var /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.dropdownChoiceSelected = function (element, selectedCondition) {
        var /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = (element.selectedOptions[0].label === 'Other, please specify…') ? 'other' : element.value;
        choiceElement.selectedText = element.selectedOptions[0].label;
        this.showOrHideFreeText(element.id, choiceElement.selectedValue);
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.selectedOptions[0].label;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    /**
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.createChoiceElementForm = function () {
        this.choiceElementForm = this.formBuilder.group({
            checkBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('checkBox')
        });
    };
    /**
     * @param {?} elementId
     * @param {?} selectedValue
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.showOrHideFreeText = function (elementId, selectedValue) {
        if (selectedValue === 'other') {
            $$2('#div_' + elementId + '_other').show();
        }
        else {
            $$2('#div_' + elementId + '_other').hide();
            $$2('#txt_other_' + elementId).val('');
        }
    };
    /**
     * @param {?} element
     * @param {?} elementId
     * @param {?} selectedCondition
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.updateFreeText = function (element, elementId, selectedCondition) {
        var /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = (element.value === 'Other') ? 'other' : element.value;
        choiceElement.selectedText = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    AssistChoiceElementComponent.prototype.specificValueInsideRange = function (checkBoxKey) {
        var _this = this;
        return function (group) {
            var /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if ((choiceControl.value === 'undefined' || choiceControl.value === '' || _this.choiceValue === undefined || _this.choiceValue === '')) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    };
    return AssistChoiceElementComponent;
}());
AssistChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-choice-element',
                template: "\n    <canvas id='Can-ImgMap'>\n\n    </canvas>\n    <form [formGroup]=\"choiceElementForm\" novalidate>\n    <div class=\"col-xs-4 col-sm-6 text-left content-padding\">\n      <label class=\"control-label DEElement\" >\n        {{choiceDataElement.label}}\n      </label>\n      <ng-container *ngIf=\"choiceDataElement.hint !== '' && choiceDataElement.hint !== undefined\">\n          <a>\n            <span class=\"glyphicon glyphicon-info-sign\" data-toggle=\"tooltip\" data-placement=\"right\" title=\"{{choiceDataElement.hint}}\"></span>\n          </a>\n        </ng-container>\n        <ng-container *ngIf=\"choiceDataElement.diagrams != undefined \">\n          <acr-hint-diagram [DataElement]=\"choiceDataElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n        </ng-container>\n        <div *ngIf=\"choiceElementForm.controls['checkBox'].invalid  && this.choiceDataElement.isRequired \" class=\"required-field\" title=\"Required Field\">\n         *\n        </div>\n    </div>\n\n    <div class=\"col-xs-8 col-sm-6 text-left content-padding\">\n      <div class=\"input-group\">\n        <div class=\"row\">\n          <div class=\"col-sm-12\">\n            <ng-container *ngIf=\"choiceDataElement.choiceInfo.length == 2\">\n              <ng-container *ngIf=\"imagePath != undefined\">\n                <div id=\"radio-inline\">\n                  <ng-container *ngFor=\"let choice of choiceDataElement.choiceInfo\">\n                    <div class=\"row\">\n                      <div class=\"col-sm-12\">\n                          <input [(ngModel)]=\"choiceValue\" id=\"{{choice.value}}_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"{{choice.value}}\"\n                          (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)\">\n                          <label for=\"{{choice.value}}_{{choiceDataElement.id}}\" class=\"rad DEValues\" >{{choice.label}}</label>\n                      </div>\n                    </div>\n                  </ng-container>\n                  <ng-container *ngIf=\"choiceDataElement.allowFreetext\">\n                    <div class=\"row\">\n                      <div class=\"col-sm-12\">\n                          <input id=\"other_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"other\"  \n                          (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'other')\">\n                          <label for=\"other_{{choiceDataElement.id}}\" class=\"rad DEValues\" >Other, please specify\u2026</label>\n                      </div>\n                    </div>\n                  </ng-container> \n                  <ng-container *ngIf=\"choiceDataElement.allowFreetext\">\n                    <div id='div_{{choiceDataElement.id}}_other' class=\"row\">\n                      <div class=\"col-sm-12\">\n                          <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\"\n                           (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)' placeholder=\"Please specify '{{choiceDataElement.label}}'\"> \n                      </div>\n                    </div>\n                  </ng-container>        \n                </div>\n              </ng-container>\n            </ng-container>\n            <ng-container *ngIf=\"choiceDataElement.choiceInfo.length != 2\">\n              <ng-container *ngIf=\"choiceDataElement.choiceInfo.length > 5 || (choiceDataElement.choiceInfo.length === 5 && choiceDataElement.allowFreetext) \">\n                  <select [(ngModel)]=\"choiceValue\" id=\"{{choiceDataElement.id}}\" (change)=\"dropdownChoiceSelected($event.target, choiceDataElement.label)\" formControlName=\"checkBox\">\n                    <option [value]=\"Select\" [selected]=\"true\">--Select--</option>\n                    <option *ngFor=\"let choice of choiceDataElement.choiceInfo\" [value]=\"choice.value\" [selected] = \"choice.value === choiceDataElement.currentValue\" >{{choice.label}}</option>\n                    <option *ngIf=\"choiceDataElement.allowFreetext\" [value]=\"other\" [selected]='other' >Other, please specify\u2026</option>\n                  </select>\n                  <div id='div_{{choiceDataElement.id}}_other' class=\"row\">\n                      <div class=\"col-sm-12\">\n                          <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\" \n                          placeholder=\"Please specify '{{choiceDataElement.label}}'\" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'>\n                      </div>\n                    </div>\n              </ng-container>\n              <ng-container *ngIf=\"choiceDataElement.choiceInfo.length === 5 && !choiceDataElement.allowFreetext\">\n                <ng-container *ngFor=\"let choice of choiceDataElement.choiceInfo\">\n                  <div id=\"radio-inline\">\n                    <div class=\"row\">\n                      <div class=\"col-sm-12\">\n                          <input [(ngModel)]=\"choiceValue\" id=\"{{choice.value}}_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"{{choice.value}}\" \n                          (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)\">\n                          <label for=\"{{choice.value}}_{{choiceDataElement.id}}\" class=\"rad DEValues\" >{{choice.label}}</label>\n                      </div>\n                    </div>\n                  </div>\n                </ng-container>\n              </ng-container>\n\n              <ng-container *ngIf=\"(choiceDataElement.choiceInfo.length < 5 && choiceDataElement.allowFreetext) || (choiceDataElement.choiceInfo.length < 5 && !choiceDataElement.allowFreetext)\">\n                  <ng-container *ngFor=\"let choice of choiceDataElement.choiceInfo\">\n                    <div id=\"radio-inline\">\n                      <div class=\"row\">\n                        <div class=\"col-sm-12\">\n                            <input  [(ngModel)]=\"choiceValue\" id=\"{{choice.value}}_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"{{choice.value}}\" \n                            (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)\">\n                            <label for=\"{{choice.value}}_{{choiceDataElement.id}}\" class=\"rad DEValues\" >{{choice.label}}</label>\n                        </div>\n                      </div>\n                    </div>\n                  </ng-container>\n                  <ng-container *ngIf=\"choiceDataElement.allowFreetext\">\n                    <div id=\"radio-inline\">\n                        <div class=\"row\">\n                          <div class=\"col-sm-12\">\n                              <input id=\"other_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"other\" \n                              (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'other')\">\n                              <label for=\"other_{{choiceDataElement.id}}\" class=\"rad DEValues\" >Other, please specify\u2026</label>\n                          </div>\n                        </div>\n                      </div>\n                      <div id='div_{{choiceDataElement.id}}_other' class=\"row\">\n                          <div class=\"col-sm-12\">\n                              <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\" \n                              placeholder=\"Please specify '{{choiceDataElement.label}}'\" (keyup)=\"updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)\">\n                          </div>\n                        </div>\n                    </ng-container>\n                </ng-container>\n            </ng-container>\n          </div>\n        </div>\n        <!-- imagemap will be displyed here -->\n        <ng-container *ngIf=\"choiceDataElement.imageMap != undefined && imagePath != undefined\">\n          <div class=\"row\">\n            <div class=\"col-sm-12\">\n              <acr-image-map [DataElement]=\"choiceDataElement\" [imagePath]=\"imagePath\"></acr-image-map>\n            </div>\n          </div>\n        </ng-container>\n      </div>\n    </div>\n    </form>\n  ",
                styles: ["\n    .DEValues {\n      background: #f5f5f5;\n      padding: 2px 10px 2px 1.5em;\n      border: 1px solid #9b9b9b; /* keeps layout from jumping */\n      border-radius: 5px;\n    }\n    input {\n      position: absolute;\n      margin-left: 5px;\n      margin-top: 5px;\n    }\n\n    div{\n        margin-top: 1px; \n    }\n    input[type=\"radio\"]:checked + label {\n      background: #1e89b5;\n      border-color: #9b9b9b;\n      color: white;\n    }input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AssistChoiceElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistChoiceElementComponent.propDecorators = {
    'choiceDataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnChoiceElement': [{ type: Output },],
    'choiceChange': [{ type: Output },],
};
var $$3 = require('jquery');
var AssistMultiChoiceElementComponent = (function () {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    function AssistMultiChoiceElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnMultiChoice = new EventEmitter();
        this.multiElements = [];
        this.multiChoiceValues = [];
        this.multiChoiceComaprisonValues = [];
        this.choiceValue = [];
    }
    /**
     * @return {?}
     */
    AssistMultiChoiceElementComponent.prototype.ngOnInit = function () {
        this.createMultiChoiceElementForm();
    };
    /**
     * @return {?}
     */
    AssistMultiChoiceElementComponent.prototype.ngAfterViewInit = function () {
        if (this.multiChoiceElement.currentValue !== undefined) {
            for (var /** @type {?} */ choice in this.multiChoiceElement.choiceInfo) {
                if (Array.isArray(this.multiChoiceElement.currentValue)) {
                    for (var _a = 0, _b = this.multiChoiceElement.currentValue; _a < _b.length; _a++) {
                        var currValue = _b[_a];
                        // this.choiceValue = this.multiChoiceElement.currentValue;
                        if (currValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                            this.choiceValue = this.multiChoiceElement.currentValue;
                            this.simulatorEngineService.addOrUpdateDataElement(this.multiChoiceElement.id, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                            var /** @type {?} */ customEvent = document.createEvent('Event');
                            $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice]).prop('checked', true);
                            customEvent.initEvent('change', true, true);
                            this.selctValue = currValue;
                            $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice])[0].dispatchEvent(customEvent);
                            break;
                        }
                    }
                }
                else {
                    if (this.multiChoiceElement.currentValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                        // this.checked = true;
                        this.simulatorEngineService.addOrUpdateDataElement(this.multiChoiceElement.id, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                        this.choiceValue = this.multiChoiceElement.currentValue;
                        var /** @type {?} */ customEvent = document.createEvent('Event');
                        $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue).prop('checked', true);
                        customEvent.initEvent('change', true, true);
                        $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue)[0].dispatchEvent(customEvent);
                    }
                }
                if (this.selctValue === this.multiChoiceElement.choiceInfo[choice].value) {
                    this.checked = this.multiChoiceElement.choiceInfo[choice].value;
                }
                else {
                    this.checked = undefined;
                }
            }
        }
    };
    /**
     * @param {?} elementId
     * @param {?} selectedCondition
     * @param {?} value
     * @param {?} event
     * @return {?}
     */
    AssistMultiChoiceElementComponent.prototype.updateMultiChoice = function (elementId, selectedCondition, value, event) {
        var /** @type {?} */ multiElement = new MultiChoiceElement();
        if (event.currentTarget.checked) {
            this.multiChoiceValues.push(value);
            this.multiChoiceComaprisonValues.push(event.currentTarget.value);
            this.checked = event.currentTarget.value;
            if (this.selctValue === event.currentTarget.value) {
                this.checked = event.currentTarget.value;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            var /** @type {?} */ index = this.multiChoiceValues.indexOf(value);
            this.checked = undefined;
            var /** @type {?} */ comparisonIndex = this.multiChoiceComaprisonValues.indexOf(event.currentTarget.value);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
        // this.returnMultiChoice.emit(multiElement);
    };
    /**
     * @return {?}
     */
    AssistMultiChoiceElementComponent.prototype.createMultiChoiceElementForm = function () {
        this.multiChoiceElementForm = this.formBuilder.group({
            multiCheckBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('multiCheckBox')
        });
    };
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    AssistMultiChoiceElementComponent.prototype.specificValueInsideRange = function (checkBoxKey) {
        var _this = this;
        return function (group) {
            var /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if (_this.multiChoiceElement.isRequired) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    };
    return AssistMultiChoiceElementComponent;
}());
AssistMultiChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-multi-choice-element',
                template: "\n    <form [formGroup]=\"multiChoiceElementForm\" novalidate>\n      <div class=\"col-xs-4 col-sm-6 text-left content-padding\">\n        <label class=\"control-label DEElement\" id=\"{{multiChoiceElement.id}}\">\n          {{multiChoiceElement.label}}\n        </label>\n        <ng-container *ngIf=\"multiChoiceElement.hint !== '' && multiChoiceElement.hint !== undefined\">\n          <a>\n            <span class=\"glyphicon glyphicon-info-sign\" data-toggle=\"tooltip\" data-placement=\"right\" title=\"{{multiChoiceElement.hint}}\"></span>\n          </a>\n        </ng-container>\n        <ng-container *ngIf=\"multiChoiceElement.diagrams != undefined \">\n          <acr-hint-diagram [DataElement]=\"multiChoiceElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n        </ng-container>\n        <div *ngIf=\"multiChoiceElementForm.controls['multiCheckBox'].invalid && !multiChoiceValues.length\" class=\"required-field\" title=\"Required Field\">\n          *\n        </div>\n      </div>\n      <div class=\"col-xs-8 col-sm-6 text-left content-padding\">\n        <div class=\"row\">\n          <div class=\"col-sm-12\">\n            <ng-container *ngFor=\"let choice of multiChoiceElement.choiceInfo\">\n              <div class=\"checkbox\" title=\"{{choice.hint}}\">\n                <label>\n                    <input [(ngModel)]=\"checked\" id=\"{{multiChoiceElement.id}}_{{choice.value}}\" type=\"checkbox\" value={{choice.value}} [checked]=\"false\" formControlName=\"multiCheckBox\" \n                    (change)=\"updateMultiChoice(multiChoiceElement.id, multiChoiceElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, $event)\">\n                    <span> {{choice.label}}</span>\n                </label>\n              </div>\n            </ng-container>\n          </div>\n        </div>\n      </div>\n    </form>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AssistMultiChoiceElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistMultiChoiceElementComponent.propDecorators = {
    'multiChoiceElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnMultiChoice': [{ type: Output },],
};
var ImageMapComponent = (function () {
    function ImageMapComponent() {
        this.$ = require('jquery');
        this.DataElements = {};
        this.FormValues = {};
        this.imageExist = true;
        this.SelectionValue = '';
    }
    /**
     * @return {?}
     */
    ImageMapComponent.prototype.ngOnInit = function () {
        if (this.DataElement === undefined) {
            return;
        }
        // const request = new XMLHttpRequest();
        // request.open('HEAD',  this.imagePath + '/' + this.DataElement.imageMap.location, false);
        // request.send();
        // if (request.status === 200) {
        //   this.imageExist = true;
        // } else {
        //   this.imageExist = false;
        // }
        this.displayValue('');
    };
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    ImageMapComponent.prototype.isInRectangle = function (mouseX, mouseY, Coordinates) {
        var /** @type {?} */ COArray = Coordinates.split(',');
        if (COArray[0] < mouseX
            && (COArray[0] + COArray[2]) > mouseX
            && COArray[1] < mouseY
            && (COArray[1] + COArray[3]) > mouseY) {
            return true;
        }
        return false;
    };
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    ImageMapComponent.prototype.isInCircle = function (mouseX, mouseY, Coordinates) {
        var /** @type {?} */ COArray = Coordinates.split(',');
        if (Math.sqrt(Math.pow((mouseX - COArray[0]), 2) + Math.pow((mouseY - COArray[1]), 2)) < COArray[2]) {
            return true;
        }
        else {
            return false;
        }
    };
    /**
     * @param {?} x
     * @param {?} y
     * @param {?} Coordinates
     * @return {?}
     */
    ImageMapComponent.prototype.isInPolygon = function (x, y, Coordinates) {
        var /** @type {?} */ COArray = Coordinates.split(',');
        var /** @type {?} */ vs = [];
        for (var /** @type {?} */ i = 0; i < COArray.length; i++) {
            var /** @type {?} */ point = [];
            point.push(COArray[i]);
            point.push(COArray[i + 1]);
            i += 1;
            vs.push(point);
        }
        var /** @type {?} */ inside = false;
        for (var /** @type {?} */ i = 0, /** @type {?} */ j = vs.length - 1; i < vs.length; j = i++) {
            var /** @type {?} */ xi = vs[i][0], /** @type {?} */ yi = vs[i][1];
            var /** @type {?} */ xj = vs[j][0], /** @type {?} */ yj = vs[j][1];
            var /** @type {?} */ intersect = ((yi > y) !== (yj > y))
                && (x < (xj - xi) * (y - yi) / (yj - yi) + xi);
            if (intersect) {
                inside = !inside;
            }
        }
        return inside;
    };
    /**
     * @param {?} e
     * @param {?} dataElement
     * @return {?}
     */
    ImageMapComponent.prototype.imageClick = function (e, dataElement) {
        var /** @type {?} */ O_height = dataElement.ImageProp.height;
        var /** @type {?} */ O_width = dataElement.ImageProp.width;
        var /** @type {?} */ $elem = this.$(e.target);
        var /** @type {?} */ N_height = $elem.height();
        var /** @type {?} */ N_width = $elem.width();
        var /** @type {?} */ offset = $elem.offset();
        var /** @type {?} */ offset_t = offset.top - this.$(window).scrollTop();
        var /** @type {?} */ offset_l = offset.left - this.$(window).scrollLeft();
        var /** @type {?} */ x = e.clientX - offset_l;
        var /** @type {?} */ y = e.clientY - offset_t;
        for (var _a = 0, _b = dataElement.ImageOptions; _a < _b.length; _a++) {
            var opt = _b[_a];
            if (opt.Shape === 'rect') {
                if (this.isInRectangle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'circle') {
                if (this.isInCircle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'poly') {
                if (this.isInPolygon(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
        }
    };
    /**
     * @param {?} val
     * @return {?}
     */
    ImageMapComponent.prototype.setValue = function (val) {
        for (var _a = 0, _b = this.DataElement.choiceInfo; _a < _b.length; _a++) {
            var optValue = _b[_a];
            if (this.DataElement.choiceInfo.length <= 5 && this.DataElement.choiceInfo.length > 0) {
                if (optValue.value === val) {
                    this.$('#' + val + '_' + this.DataElement.id).prop('checked', true);
                    break;
                }
                else {
                    this.$('#' + optValue.value + '_' + this.DataElement.id).prop('checked', false);
                }
            }
            else {
                if (optValue.value === val) {
                    this.$('#' + this.DataElement.id).val(optValue.value);
                    var /** @type {?} */ customEvent = document.createEvent('Event');
                    customEvent.initEvent('change', true, true);
                    this.$('#' + this.DataElement.id)[0].dispatchEvent(customEvent);
                    break;
                }
            }
        }
        this.DataElement.currentValue = val;
        // this.FormValues[this.DataElement.id] = val;
    };
    /**
     * @param {?} val
     * @return {?}
     */
    ImageMapComponent.prototype.displayValue = function (val) {
        if (val === '') {
            this.SelectionValue = 'Image Map Diagram';
        }
        else {
            this.SelectionValue = 'Selected Value : ' + val;
        }
    };
    return ImageMapComponent;
}());
ImageMapComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-image-map',
                template: "\n    <div class=\"row\">\n      <div class=\"col-sm-4 text-center\">\n        OR\n      </div>\n    </div>\n    <div class=\"row\">\n      <div class=\"col-sm-12 text-left\">\n        Select value from image:-\n          <button type=\"button\" class=\"btn btn-default\" data-toggle=\"modal\" attr.data-target=\"#{{'imgMap_Modal_'+DataElement.id}}\">\n          <span class=\"glyphicon glyphicon-picture\" aria-hidden=\"true\" data-toggle=\"tooltip\" data-placement=\"top\" title=\"Image Map\"></span>\n        </button>\n      </div>\n    </div>\n\n    <ng-container *ngIf=\"imagePath != undefined\">\n      <div class=\"modal fade img-modal\" tabindex=\"-1\" role=\"dialog\" attr.id=\"{{'imgMap_Modal_'+DataElement.id}}\" aria-labelledby=\"mySmallModalLabel\">\n        <div class=\"modal-dialog modal-lg\" role=\"document\">\n          <!-- <div class=\"modal-dialog modal-lg\" role=\"document\" [ngStyle]=\"{'width':DataElement.ImagePath.width + 30}\"> -->\n          <div class=\"modal-content\">\n            <div class=\"modal-header\">\n              <h4 class=\"modal-title\">\n                {{SelectionValue}}\n              </h4>\n              <button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\">\n                <span aria-hidden=\"true\">\u00D7</span>\n              </button>\n            </div>\n            <div class=\"modal-body\">\n              <div class=\"row\">\n                <div class=\"col-md-12\">\n                  <ng-container *ngIf=\"imageExist == true\">\n                    <img class=\"ImgOption danger\" alt=\"No Image Available!!!\" data-dismiss=\"modal\" attr.id=\"{{'imgMap_Img_'+DataElement.id}}\"\n                      (click)=\"imageClick($event,DataElement);\" attr.data-elementID=\"{{DataElement.id}}\" attr.usemap=\"#{{'imgMap_'+DataElement.id}}\"\n                      src=\"{{imagePath}}/{{DataElement.imageMap.location}}\">\n                    <map name=\"{{'imgMap_'+DataElement.id}}\">\n                      <ng-container *ngFor=\"let imgOpt of DataElement.imageMap.map.areas\">\n                        <area attr.shape=\"{{imgOpt.shape}}\" attr.imgID=\"{{'imgMap_Img_'+DataElement.id}}\" attr.coords=\"{{imgOpt.coords}}\" attr.alt=\"{{imgOpt.choiceValue}}\"\n                          (mouseover)='displayValue(imgOpt.choiceValue);' (mouseout)='displayValue(\"\");'\n                          (click)=\"setValue(imgOpt.choiceValue);\" data-dismiss=\"modal\">\n                      </ng-container>\n                    </map>\n                  </ng-container>\n\n                  <ng-container *ngIf=\"imageExist == false\">\n                    <div class=\"\">\n                      No Image Map Available...\n                    </div>\n                  </ng-container>\n                </div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </ng-container>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
ImageMapComponent.ctorParameters = function () { return []; };
ImageMapComponent.propDecorators = {
    'DataElement': [{ type: Input },],
    'DataElements': [{ type: Input },],
    'FormValues': [{ type: Input },],
    'imagePath': [{ type: Input },],
};
var ComputedDataElement = (function (_super) {
    __extends(ComputedDataElement, _super);
    function ComputedDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ComputedDataElement;
}(BaseDataElement));
var ComputedDataElementCreationService = (function (_super) {
    __extends(ComputedDataElementCreationService, _super);
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     * @param {?} computedValueCreationService
     * @param {?} decisionPointsCreationService
     */
    function ComputedDataElementCreationService(diagramService, arrayCheckerService, computedValueCreationService, decisionPointsCreationService) {
        var _this = _super.call(this, diagramService) || this;
        _this.arrayCheckerService = arrayCheckerService;
        _this.computedValueCreationService = computedValueCreationService;
        _this.decisionPointsCreationService = decisionPointsCreationService;
        _this.elementType = 'ComputedDataElement';
        return _this;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    ComputedDataElementCreationService.prototype.createElement = function (data) {
        var /** @type {?} */ dataElement = new ComputedDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.computeValue = this.computedValueCreationService.createComputedValue(data);
        if (data.DecisionPoint) {
            dataElement.decisionPoints = this.decisionPointsCreationService.createDecisionPoints(data.DecisionPoint);
        }
        return dataElement;
    };
    return ComputedDataElementCreationService;
}(DataElementCreationBaseService));
ComputedDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ComputedDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
    { type: ComputedValueCreationService, },
    { type: DecisionPointsCreationService, },
]; };
var $$4 = require('jquery');
var AssistReportTextComponent = (function () {
    function AssistReportTextComponent() {
        this.allReportTexts = [];
        this.sections = [];
        setInterval(function () {
        }, 1000);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    AssistReportTextComponent.prototype.ngOnChanges = function (changes) {
        this.mainReportTexts = new MainReportText();
        this.onSelect(this.selectedSectionId);
    };
    /**
     * @param {?} sectionId
     * @return {?}
     */
    AssistReportTextComponent.prototype.onSelect = function (sectionId) {
        this.selectedSectionId = sectionId;
        this.sections = [];
        this.selectedSection = null;
        for (var /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].reportText !== '') {
                this.sections.push(section);
            }
        }
        if (this.sections.length > 1) {
            if (sectionId === 'undefined' || sectionId === undefined || sectionId === 'All') {
                this.allTextReport = [];
                for (var /** @type {?} */ section in this.reportText.allReportText) {
                    if (this.reportText.allReportText[section].reportText !== '') {
                        var /** @type {?} */ textReport = new AllTextReport();
                        textReport.heading = section;
                        textReport.content = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
                        this.allTextReport.push(textReport);
                    }
                }
                // $('#allTextReport').html(allText);
                this.selectedSectionId = 'All';
            }
        }
        else {
            sectionId = this.sections[0];
        }
        for (var /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].sectionId === sectionId) {
                this.selectedSection = this.reportText.allReportText[section].reportText;
                this.selectedSection = this.reportText.reportTextMainContent + ((this.selectedSection !== undefined && this.selectedSection !== '') ? this.removeEmptyLine(this.selectedSection) : '');
                break;
            }
        }
        this.mainReportTexts = new MainReportText();
        this.allReportTexts = [];
        for (var /** @type {?} */ section in this.reportText.allReportText) {
            var /** @type {?} */ allreportText = new AllReportText();
            allreportText.reportText = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
            allreportText.sectionId = this.reportText.allReportText[section].sectionId;
            this.allReportTexts.push(allreportText);
        }
        this.mainReportTexts.allReportText = this.allReportTexts;
        this.mainReportTexts.reportTextMainContent = this.reportText.reportTextMainContent;
    };
    /**
     * @param {?} inputText
     * @return {?}
     */
    AssistReportTextComponent.prototype.removeEmptyLine = function (inputText) {
        if (inputText.trim().length !== 0) {
            var /** @type {?} */ lines = inputText.split('\n');
            var /** @type {?} */ uniquelines_1 = [];
            lines.forEach(function (line, i) {
                if (line.trim().length !== 0) {
                    uniquelines_1.push(line);
                }
            });
            return uniquelines_1.join('\n');
        }
    };
    return AssistReportTextComponent;
}());
AssistReportTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-report-text',
                template: "\n    <ng-container>\n        <div class=\"panel panel-group panel-default no-bottom-margin\">\n            <div class=\"panel-heading findings\">Report Text: \n                <div>\n                    <select id=\"ddlSections\" (change)=\"onSelect($event.target.value)\" style=\"text-transform: capitalize\">\n                        <option *ngIf=\"sections.length > 1\" [value]=\"All\" [selected]=\"All\">All</option>\n                        <option *ngFor=\"let Section of sections\" [value]=\"Section\" >{{Section}}</option>\n                    </select>\n                </div>\n            </div>\n            <div class=\"panel-body\" >\n                <div class=\"reportText-content\">\n                    <ng-container *ngIf=\"selectedSectionId !=='All'\">\n                        <div [innerHTML]=\"selectedSection\"  class=\"split-length-word all-reportText-content\">\n                        </div>\n                    </ng-container>\n                    <ng-container *ngIf=\"selectedSectionId ==='All'\">\n                        <ng-container *ngFor=\"let textReport of allTextReport\">\n                            <div class=\"all-reporttext-heading\">\n                                {{textReport.heading}}\n                            </div>\n                            <div [innerHTML]=\"textReport.content\"  class=\"split-length-word all-reportText-content\">\n                            </div> \n                        </ng-container>\n                    </ng-container>\n                </div>\n            </div>\n        </div>\n    </ng-container>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
AssistReportTextComponent.ctorParameters = function () { return []; };
AssistReportTextComponent.propDecorators = {
    'reportText': [{ type: Input },],
};
var components = [AcrAssistSimulatorComponent, AssistDataElementComponent, HintDiagramComponent, SlideComponent, CarouselComponent,
    AssistNumericElementComponent, AssistChoiceElementComponent, AssistMultiChoiceElementComponent, ImageMapComponent, AssistReportTextComponent];
var AcrAssistSimulatorModule = (function () {
    function AcrAssistSimulatorModule() {
    }
    return AcrAssistSimulatorModule;
}());
AcrAssistSimulatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    CoreModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: components,
                providers: [TemplateManagerService,
                    DiagramService,
                    CarouselConfig,
                    ArrayCheckerService,
                    ConditionsCreationService,
                    DecisionPointsCreationService,
                    ComputedValueCreationService,
                    SimulatorEngineService,
                    { provide: CreationServiceInjectorToken, useClass: ChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: MultipleChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: NumericDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: IntegerDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: GlobalValueCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: ComputedDataElementCreationService, multi: true }
                ],
                exports: components
            },] },
];
/**
 * @nocollapse
 */
AcrAssistSimulatorModule.ctorParameters = function () { return []; };
var Dictionary = (function () {
    function Dictionary() {
        this.items = {};
        this.count = 0;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.ContainsKey = function (key) {
        return this.items.hasOwnProperty(key);
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.Count = function () {
        return this.count;
    };
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    Dictionary.prototype.Add = function (key, value) {
        if (!this.items.hasOwnProperty(key)) {
            this.count++;
        }
        this.items[key] = value;
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.Remove = function (key) {
        var /** @type {?} */ val = this.items[key];
        delete this.items[key];
        this.count--;
        return val;
    };
    /**
     * @param {?} key
     * @return {?}
     */
    Dictionary.prototype.Item = function (key) {
        return this.items[key];
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.Keys = function () {
        var /** @type {?} */ keySet = [];
        for (var /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                keySet.push(prop);
            }
        }
        return keySet;
    };
    /**
     * @return {?}
     */
    Dictionary.prototype.Values = function () {
        var /** @type {?} */ values = [];
        for (var /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                values.push(this.items[prop]);
            }
        }
        return values;
    };
    return Dictionary;
}());
var GlobalsService = (function () {
    /**
     * @param {?} http
     */
    function GlobalsService(http$$1) {
        this.http = http$$1;
        this.defaultModule = 'assets/XMLFIles/Hello_RADS/Hello_RADS.xml';
        this.XMLList = new Dictionary();
    }
    /**
     * @return {?}
     */
    GlobalsService.prototype.getDefaultModulePath = function () {
        return this.http.get(this.defaultModule).map(function (res) { return res.text(); });
    };
    return GlobalsService;
}());
GlobalsService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
GlobalsService.ctorParameters = function () { return [
    { type: Http, },
]; };
var $$5 = require('jquery');
var ViewUploadLoaderComponent = (function () {
    /**
     * @param {?} globalsService
     */
    function ViewUploadLoaderComponent(globalsService) {
        this.onFileSelected = new EventEmitter();
        this.globalsService = globalsService;
    }
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    ViewUploadLoaderComponent.prototype.onFileContentRead = function (fileDetails) {
        this.selectedXML = fileDetails;
        if (this.globalsService.XMLList.ContainsKey(fileDetails.fileLabel)) {
            this.globalsService.XMLList.Remove(fileDetails.fileLabel);
        }
        this.globalsService.XMLList.Add(fileDetails.fileLabel, fileDetails);
        this.onFileSelected.emit(fileDetails);
    };
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    ViewUploadLoaderComponent.prototype.onFileClick = function (fileDetails) {
        this.selectedXML = fileDetails;
        this.onFileSelected.emit(fileDetails);
        $$5('#xmlOnlyMsg').hide();
    };
    return ViewUploadLoaderComponent;
}());
ViewUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-view-upload-loader',
                template: "\n\n      <ul class=\"nav nav-sidebar\">\n        <li class=\"header\">Want to try your assist module?</li>\n    \n        <li class=\"fileUploader\">\n          <acr-file-upload-loader (onFileContentRead)=\"onFileContentRead($event)\"></acr-file-upload-loader>\n        </li>\n      </ul>\n      <ul class=\"nav nav-sidebar\">\n        <li [ngClass]=\"{'active':(selectedXML != 'undefined' && selectedXML.fileLabel == file.fileLabel)}\" *ngFor=\"let file of globalsService.XMLList.Values().reverse()\">\n            <a href=\"#\" (click)=\"onFileClick(file)\">{{file.fileLabel}}</a>\n    \n        </li>\n\n      </ul>\n  ",
                styles: ["\n\n    /* Sidebar navigation */\n\n    .nav-sidebar {\n      background-color: #2e3752;\n    }\n\n    .nav-sidebar>li>a {\n      padding: 0px !important;\n      color: white;\n      border-left: 3px solid transparent;\n      border-bottom: 1px solid #464850;\n      margin-top: 5px; \n    }\n\n    .nav-sidebar>.active>a {\n      border-left-color: white ;\n    }\n\n    .nav-sidebar>.active>a,\n    .nav-sidebar>.active>a:hover,\n    .nav-sidebar>.active>a:focus,\n    .nav-sidebar>li>a:hover {\n      color: #fff;\n      background-color: #1e282c;\n      font-weight: bold;\n    }\n    .nav-sidebar>li.fileUploader {\n      text-align: center;\n      padding: 10px 25px 1px 15px;\n      font-size: 12px;\n      top: 7px;\n    }\n    .nav-sidebar>li.header {\n      color:white;\n      background: #5c5d5f;\n      padding: 0px 33px 0px 11px;\n      font-size: 13px;\n    }\n\n    .nav-sidebar>li.header.module-header {\n      font-size: 16px;\n        font-weight: bold;\n        text-align: center;\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .cursor {\n      cursor: pointer;\n    }\n\n    .navbar-fixed-top {\n      border: 0;\n    }\n    @media (min-width: 768px) {\n      .sidebar {\n        position: fixed;\n        top: 51px;\n        bottom: 0;\n        left: 0;\n        z-index: 1000;\n        display: block;\n        padding: 20px;\n        overflow-x: hidden;\n        overflow-y: auto;\n        /* Scrollable contents if viewport is shorter than content. */\n        background-color: #2e3752;\n        border-right: 1px solid #eee;\n      }\n    }\n\n\n\n    .navbar-blue {\n      background-color: #2e3752;\n    }\n\n    .navbar-blue .navbar-brand {\n      color: #fff;\n    }\n\n\n    /*\n     * Main content\n     */\n\n    .main {\n      padding: 0px;\n    }\n\n    @media (min-width: 768px) {\n      .main {\n        padding-right: 40px;\n        padding-left: 40px;\n      }\n    }\n\n    .main .page-header {\n      margin-top: 0;\n    }\n  "]
            },] },
];
/**
 * @nocollapse
 */
ViewUploadLoaderComponent.ctorParameters = function () { return [
    { type: GlobalsService, },
]; };
ViewUploadLoaderComponent.propDecorators = {
    'onFileSelected': [{ type: Output },],
};
var FileDetails = (function () {
    /**
     * @param {?} fileLabel
     * @param {?} fileName
     * @param {?} fileContents
     */
    function FileDetails(fileLabel, fileName, fileContents) {
        this.fileLabel = fileLabel;
        this.fileName = fileName;
        this.fileContents = fileContents;
    }
    return FileDetails;
}());
var $$6 = require('jquery');
var FileUploadLoaderComponent = (function () {
    /**
     * @param {?} configService
     */
    function FileUploadLoaderComponent(configService) {
        this.configService = configService;
        this.onFileContentRead = new EventEmitter();
        this.fileReader = new FileReader();
    }
    /**
     * @return {?}
     */
    FileUploadLoaderComponent.prototype.ngOnInit = function () {
        this.hideMessage();
        this.showDefaultModule();
    };
    /**
     * @param {?} $event
     * @return {?}
     */
    FileUploadLoaderComponent.prototype.changeListener = function ($event) {
        var /** @type {?} */ fileName;
        fileName = $event.target.value;
        if (fileName.includes('.xml') || fileName.includes('.Xml') || fileName.includes('.XML') ||
            fileName.includes('.zip') || fileName.includes('.Zip') || fileName.includes('.ZIP')) {
            this.hideMessage();
            this.readThis($event.target);
        }
        else {
            if (fileName !== '' && fileName !== undefined) {
                $$6('#xmlOnlyMsg').show();
            }
        }
    };
    /**
     * @return {?}
     */
    FileUploadLoaderComponent.prototype.hideMessage = function () {
        $$6('#xmlOnlyMsg').hide();
    };
    /**
     * @param {?} inputValue
     * @return {?}
     */
    FileUploadLoaderComponent.prototype.readThis = function (inputValue) {
        var _this = this;
        this.readFile = inputValue.files[0];
        var /** @type {?} */ self = this;
        var /** @type {?} */ extensionStartPosition = self.readFile.name.lastIndexOf('.');
        this.fileReader.onloadend = function (e) {
            self.onFileContentRead.emit(new FileDetails(self.readFile.name.substring(0, extensionStartPosition), self.readFile.name, _this.fileReader.result));
        };
        this.fileReader.readAsText(this.readFile);
    };
    /**
     * @return {?}
     */
    FileUploadLoaderComponent.prototype.showDefaultModule = function () {
        var _this = this;
        this.configService.getDefaultModulePath()
            .subscribe(function (data) {
            var /** @type {?} */ self = _this;
            self.onFileContentRead.emit(new FileDetails('Hello RADS', 'Hello_RADS.xml', data));
        });
    };
    return FileUploadLoaderComponent;
}());
FileUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-file-upload-loader',
                template: "\n    <!-- <div class = \"row\">\n      <div class= \"col-sm-12\">\n          <div class=\"panel panel-default\">\n              <div class=\"panel-heading\"><strong>Select  the Template file</strong></div>\n              <div class=\"panel-body\">\n                  <div class=\"row\">\n                        <div class=\"col-sm-12 col-md-4 col-xs-12\"> Select the file to be uploaded</div>\n                        <div class=\"col-sm-12 col-md-8 col-xs-12\"><input type=\"file\" accept=\".xml\" (change)=\"changeListener($event)\"></div>\n                  </div>\n              </div>\n            </div>\n      </div>\n    </div> -->\n\n    <input id=\"xmlFileUpload\" class=\"inputfile\" type=\"file\" accept=\".xml\" (change)=\"changeListener($event)\" (click)=\"hideMessage()\">\n    <label for=\"xmlFileUpload\" class=\"upload-button-size\" title=\"Choose a Module\">Choose a Module</label><br>\n    <div id=\"xmlOnlyMsg\" class=\"xml-only-msg\"> Only XML files are supported !!!</div>\n  ",
                styles: ["\n    input[type=file].inputfile {\n      width: 0.1px;\n      height: 0.1px;\n      opacity: 0;\n      overflow: hidden;\n      position: absolute;\n      z-index: -1;\n      margin: 0;\n    }\n\n    input[type=file].inputfile+label:active,\n    input[type=file].inputfile+label {\n      max-width: 100%;\n      font-size: 1.5rem;\n      font-weight: 700;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      cursor: pointer;\n      display: inline-block;\n      overflow: hidden;\n      display: inline-block;\n      color: #f1e5e6;\n      background-color: #d3394c;\n      text-indent: 0px;\n      width: 130px;\n    }\n\n    input[type=file].inputfile+label:hover {\n      background-color: #722040;\n    }\n\n    input[type=file].inputfile+label {\n      cursor: pointer;\n      /* \"hand\" cursor */\n    }\n\n    input[type=file].inputfile:hover+label {\n      outline: 1px dotted #000;\n      outline: -webkit-focus-ring-color auto 5px;\n    }\n\n    .right-fixed {\n      position: fixed;\n      right: 0px;\n    }\n\n    .row.report-text-top-margin.right-align{\n      width: 80%;\n      margin-left: 135px;\n    }\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    body {\n      margin: 2em;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: auto;\n      line-height: 25px;\n      width: 100%;\n      font-weight: bold;\n    }\n\n    .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n      width: 100%;\n      min-width: 180px;\n      max-width: 280px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n      margin-top: 5px;\n    }\n\n    button:hover,\n    button:focus,\n    button.active,\n    .btn-default:hover,\n    .btn-default:focus,\n    .item.active,\n    .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .control-label {\n      text-align: left !important;\n    }\n\n    .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 45px;\n      font-size: 16px;\n      text-align: left;\n    }\n\n    .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n    }\n\n    .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .panel-default {\n      min-width: 100%;\n    }\n\n    #footer {\n      position: fixed;\n      bottom: 0;\n    }\n\n    .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .modal-dialog {\n      top: 100px;\n      margin-left: 50% !important;\n    }\n\n    .required-field {\n      /* border: 1px solid red; */\n      /* border-radius: 5px; */\n      padding: 5px;\n      font-size: 16px;\n      color: red;\n      /* width: 120px; */\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    .xml-only-msg {\n      border: 1px solid red;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: white;\n      width: 223px;\n      display: inline-block;\n      font-weight: bold;\n    }\n\n    @media (min-width: 400px) and (max-width: 1024px) {\n      .xml-only-msg {\n        width: 120px;\n      }\n    }\n\n    @media (max-width: 475px)  {\n      .xml-only-msg {\n        color: #000000\n      }\n    }\n    .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .col-md-10 {\n      left: 200px;\n    }\n\n    .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    select {\n      height: 35px;\n      border-radius: 5px;\n      max-width: 280px;\n      width: 100%;\n    }\n\n    .findings select{\n      max-width: 150px;\n      margin-top: -3px;\n    }\n    .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .findings div {\n      color: #363636 !important;\n      margin-left: 100px !important;\n      margin-top: -23.5px !important;\n      height: 30px;\n    }\n\n    .findings div select {\n      text-transform: capitalize;\n    }\n\n    .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .tooltip-arrow {\n      display: none !important;\n    }\n\n    .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    a:hover {\n      text-decoration: none !important;\n    }\n\n    .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    .reportText-panel {\n      width: 90%;\n      margin-left: 2%;\n    }\n\n    .reportText-body {\n      margin-left: 2%;\n    }\n\n    .top-Index {\n      z-index: 99999 !important;\n    }\n\n\n    /* Master Styles */\n\n    h1 {\n      color: #369;\n      font-family: Arial, Helvetica, sans-serif;\n      font-size: 250%;\n    }\n\n    h2,\n    h3 {\n      color: #444;\n      font-family: Arial, Helvetica, sans-serif;\n      font-weight: lighter;\n    }\n\n    .div-simulator-container {\n      margin: 0;\n    }\n\n\n    /*Apply background color for div having checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]:checked+div {\n      background-color: #1e89b5 !important;\n      border: 1px solid #9b9b9b;\n      color: #ffffff;\n    }\n\n\n    /*Apply background color for div having no checked radio button*/\n\n    .div-simulator-container input[type=\"radio\"]+div {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .checkbox>label {\n      background-color: #f5f5f5 !important;\n      border: 1px solid #9b9b9b;\n      border-radius: 5px;\n      height: 25px;\n      line-height: 25px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-left: -15px;\n      margin-top: 6px;\n    }\n\n    .div-simulator-container .full-width span {\n      font-weight: bold;\n    }\n\n\n    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;\n        border: 1px solid #9B9B9B;\n        }*/\n\n    .div-simulator-container .DEElement {\n      color: #363636;\n      letter-spacing: -0.37px;\n      word-wrap: break-word;\n    }\n\n    .div-simulator-container .DEValues {\n      /*font-size: 12px;*/\n      color: #4a4a4a;\n      letter-spacing: -0.29px;\n    }\n\n\n    /* CHECKBOX OVERWRITE STYLES */\n\n    .div-simulator-container .rad {\n      cursor: pointer;\n      -moz-user-select: none;\n       -ms-user-select: none;\n           user-select: none;\n      -webkit-user-select: none;\n      -webkit-touch-callout: none;\n    }\n\n    .div-simulator-container .rad>input {\n      /* HIDE ORG RADIO & CHECKBOX */\n      visibility: hidden;\n      position: absolute;\n    }\n\n    .div-simulator-container [type=\"radio\"]+span::before {\n      content: \"\";\n      display: inline-block;\n      width: 9px;\n      height: 9px;\n      border-radius: 1em;\n      border: 0.1px solid #fff;\n      -webkit-box-shadow: 0 0 0 1px #57aed0;\n              box-shadow: 0 0 0 1px #57aed0;\n      margin-right: 4px;\n      -webkit-transition: 0.5s ease all;\n      transition: 0.5s ease all;\n      margin-left: -15px;\n    }\n\n    [type=\"radio\"]:checked+span::before {\n      background: #57aed0;\n      -webkit-box-shadow: 0 0 0 2px #57aed0;\n              box-shadow: 0 0 0 2px #57aed0;\n      margin-top: auto;\n      /*margin-left:-15px;*/\n    }\n\n    .div-simulator-container .reportText {\n      font-size: 14px;\n      color: #363636;\n      letter-spacing: -0.49px;\n    }\n\n    .div-simulator-container button:hover,\n    .div-simulator-container button:focus,\n    .div-simulator-container button.active,\n    .div-simulator-container .btn-default:hover,\n    .btn-default:focus,\n    .div-simulator-container .item.active,\n    .div-simulator-container .btn-default.active {\n      background: #1e89b5 !important;\n      color: #ffffff !important;\n    }\n\n    .div-simulator-container .hideInput {\n      visibility: hidden;\n      margin-left: 5px !important;\n    }\n\n    .div-simulator-container .panel {\n      background-color: transparent;\n    }\n\n    .logo {\n      height: 30px;\n      width: 250px;\n    }\n\n    .navbar-blue {\n      background-color: #00205b !important;\n      color: #fff;\n    }\n\n    .navbar-brand-text {\n      font-size: 30px;\n      color: #fff;\n      font-weight: normal;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .close {\n      margin-top: -20px !important;\n    }\n\n\n    /*.full-width {\n            width: 320px !important;\n        }*/\n\n    #myNav.affix {\n      width: 483px;\n      top: 100;\n    }\n\n    #Can-ImgMap {\n      pointer-events: none;\n      position: absolute;\n      opacity: 0.5;\n    }\n\n\n    /* Styles for Assist bootstrap*/\n\n    .div-simulator-container .control-label {\n      text-align: left !important;\n    }\n\n    .div-simulator-container .box-style {\n      text-decoration: none;\n      color: #363636 !important;\n      border-radius: 3px;\n      padding: 5px;\n      font-weight: bold !important;\n      width: 75%;\n    }\n\n    .div-simulator-container .findings {\n      color: #ffffff !important;\n      background-color: #5295b1 !important;\n      border-color: #5295b1 !important;\n      background-image: none !important;\n      font-weight: bold;\n      text-transform: capitalize;\n      height: 40px;\n    }\n\n    .div-simulator-container .table-row {\n      display: table-row;\n      width: auto;\n      clear: both;\n    }\n\n    .div-simulator-container .table-cell {\n      display: table-cell;\n      width: 475px;\n      font-size: 12px;\n      background-color: transparent;\n      color: black;\n      height: 25px;\n      line-height: 25px;\n      padding: 1px;\n      border-bottom: none;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      width: 10% !important;\n      vertical-align: middle;\n    }\n\n    .div-simulator-container .panel-default {\n      min-width: 600px;\n      margin: 0 !important;\n      background-color: white;\n    }\n\n    .div-simulator-container .footerBlock {\n      position: fixed;\n      bottom: 55px;\n    }\n\n    .div-simulator-container .row-style {\n      bottom: 5px;\n      position: fixed;\n      top: 55px;\n      overflow: auto;\n      width: 100%;\n    }\n\n    .div-simulator-container .modal-dialog {\n      top: 100px;\n      /*margin-left: 50% !important;*/\n      margin-left: 0 !important;\n    }\n\n    .div-simulator-container .required-field {\n      border: 1px solid #edd1d1;\n      border-radius: 5px;\n      padding: 5px;\n      font-size: 12px;\n      color: #cd5c5c;\n      width: 125px;\n    }\n\n    .div-simulator-container .col-per-10 {\n      border: 1px solid blue;\n      padding: 15px 10px 15px 10px;\n      border-radius: 10px;\n      height: auto;\n      width: 10%;\n      float: left;\n      position: fixed;\n      min-height: 1px;\n    }\n\n    .div-simulator-container .btn-group>.btn:first-child {\n      margin-left: 0;\n      width: 165px;\n      margin-top: 10px;\n    }\n\n    .div-simulator-container .col-md-10 {\n      left: 200px;\n    }\n\n    .div-simulator-container .module-header {\n      font-family: \"Helvetica Neue\", Helvetica, Arial, sans-serif !important;\n      margin-left: -135px;\n      margin-top: -15px;\n      font-size: 14px;\n      font-weight: bold;\n      color: #363636;\n    }\n\n    .div-simulator-container .btn-group-justified {\n      padding-left: 15px;\n    }\n\n    .div-simulator-container select {\n      height: 28px;\n      border-radius: 5px;\n    }\n\n    .div-simulator-container .panel-body {\n      padding: 10px !important;\n    }\n\n    .div-simulator-container .fixed-keydiagram {\n      position: fixed !important;\n      float: right;\n      padding-right: 0px !important;\n      margin-right: 10px;\n      padding-left: 25px !important;\n    }\n\n    .div-simulator-container .center-align {\n      text-align: center;\n      width: 160px !important;\n      padding: 0px !important;\n    }\n\n    .div-simulator-container .center-align div {\n      width: 200px;\n      margin-left: -10px;\n    }\n\n    .div-simulator-container .findings div {\n      color: #363636 !important;\n      margin-left: 97px !important;\n      margin-top: -29.5px !important;\n      height: 30px;\n    }\n\n    .div-simulator-container .findings div select {\n      text-transform: capitalize;\n    }\n\n    .div-simulator-container .modal-backdrop {\n      top: 10000px !important;\n    }\n\n    .div-simulator-container .tooltip-arrow {\n      display: none !important;\n    }\n\n    .div-simulator-container .other-reportSection {\n      font-weight: normal;\n      margin-top: -10px;\n      margin-left: 15px;\n    }\n\n    .div-simulator-container a:hover {\n      text-decoration: none !important;\n    }\n\n    .div-simulator-container .no-btm-margin-table {\n      margin-bottom: 0px !important;\n    }\n\n    .div-simulator-container .adjust-diagram {\n      margin-top: 56px;\n      right: 20px !important;\n    }\n\n    .adjust-diagram-image {\n      top: 0px !important;\n      margin-top: 0px !important;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .tab-content {\n        padding: 5px;\n      }\n    }\n\n    @media (min-width: 768px) {\n      #page-content-wrapper {\n        padding: 0px 20px;\n        margin-top: 15px;\n      }\n    }\n\n    #sidebar-wrapper {\n      left: 175px;\n      margin-left: -175px;\n    }\n\n    #rowContent {\n      padding-bottom: 120px;\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .fixed-reportText {\n        width: 1064px;\n      }\n    }\n\n    @media only screen and (min-width: 1824px) {\n      .fixed-reportText {\n        width: 1260px;\n      }\n    }\n\n    @media only screen and (min-width: 1224px) {\n      .modal-lg {\n        left: 0;\n        /* left: -250px; */\n      }\n    }\n\n    .form-group {\n      margin-bottom: 15px;\n    }\n\n    .control-label {\n      margin-top: 0;\n      margin-left: 0;\n    }\n\n    .div-simulator-container .checkbox>label {\n      height: 30px;\n      line-height: 30px;\n    }\n\n    .div-simulator-container .checkbox>label>input[type=\"checkbox\"] {\n      margin-top: 8px;\n    }\n\n    .div-simulator-container select {\n      height: 30px;\n      border-radius: 5px;\n      font-size: 12px;\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group {\n      width: 280px;\n    }\n\n    .div-simulator-container .input-group .form-control {\n      border-radius: 5px;\n      -webkit-box-shadow: none;\n              box-shadow: none;\n      border: 1px solid #969696;\n    }\n\n    .div-simulator-container .imgMap-table-cell {\n      padding-left: 10px;\n    }\n\n    @media (min-width: 1224px) {\n      .modal-lg {\n        width: 630px;\n      }\n    }\n\n    .tableImagemap {\n      table-layout: fixed;\n    }\n\n    @media (min-width: 1850px) {\n      .modal-lg {\n        width: 900px;\n      }\n      .tableImagemap {\n        table-layout: inherit;\n      }\n    }\n\n    .col-centered {\n      float: none;\n      margin: 0 auto;\n    }\n\n    .checkbox {\n      max-width: 280px;\n    }\n\n    [type=\"number\"] {\n      max-width: 280px;\n      /*margin-left: -15px;*/\n    }\n\n    .input-group {\n      width: 100%;\n    }\n\n    @media (min-width:1441px) {\n      .DEValues {\n        /*min-width: 280px;\n        max-width: 280px;*/\n        height: auto;\n      }\n    }\n\n    @media (max-width:1024px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    @media (min-width:1921px) {\n      .adjust-diagram-image {\n        width: 50%;\n      }\n    }\n\n    .row {\n      font-weight: bold;\n    }\n\n    .carousel-item.item img {\n      width: 100% !important;\n    }\n\n    .carousel-indicators {\n      display: none !important;\n    }\n\n    .display-inline {\n      display: inline;\n    }\n\n    .font-weight-normal {\n      font-weight: normal;\n    }\n\n    .font-weight-bold {\n      font-weight: bold;\n    }\n\n    .color-white {\n      color: #ffffff;\n    }\n\n    .bottom-margin{\n      margin-bottom: 25px;\n    }\n\n    .reportText-content {\n      white-space: pre-line; \n      font-weight: bold;\n      margin: -40px 0px;\n      height: -webkit-fit-content;\n      height: -moz-fit-content;\n      height: fit-content;\n    }\n\n    .no-bottom-margin {\n      margin-bottom: 0px !important;\n    }\n    .reportText-main-content{\n      font-size: 16px;\n    }\n\n    .split-length-word {\n      word-break: break-all;\n      text-align: left;\n      margin: 0px 0px;\n    }\n\n    .img-max-width {\n      width: 70% !important;\n    }\n\n    .keydiagram {\n      text-align: center;\n      margin-top: 10px;\n    }\n\n    .report-text-top-margin {\n      margin-top: 15px;\n    }\n\n    input[type=number]::-webkit-inner-spin-button, \n    input[type=number]::-webkit-outer-spin-button { \n        -webkit-appearance: none;\n        -moz-appearance: none;\n        margin: 0; \n    }\n\n    input[type=\"number\"]:hover,\n    input[type=\"number\"]:focus,\n    input[type=\"number\"] {\n        -moz-appearance: textfield;\n    }\n\n    .numeric-align {\n      display: inline;\n    }\n\n    input[type=\"text\"] {\n    max-width: 280px;\n    margin-left: 0px !important;\n    border-radius: 5px !important;\n    text-transform: capitalize;\n    }\n\n    .all-reporttext-heading {\n      text-decoration: underline;\n      font-weight: bold;\n      text-transform: capitalize;\n      font-size: 18px;\n      margin-top: -50px;\n      text-align: left;\n    }\n\n    .all-reportText-content {\n      margin-top: -10px;\n    }\n\n    .split-length-word.all-reportText-content {\n      text-align: justify;\n      word-break: unset;\n    }\n\n    .fixed-report-text-sidebar {\n      position: fixed;\n      right: 0;\n      width: 45%;\n    }\n\n    .fixed-report-text-footer {\n      position: fixed;\n      left: 15 !important;\n      bottom: 0;\n      background-color: white;\n    }\n\n    .left-margin {\n      margin-left: 60px;\n      width: 90%;\n    }\n\n    .overflow {\n      /* max-height: 500px; */\n      overflow-x: hidden;\n    }\n\n    @media (max-width: 650px) {\n  \n\n      .left-margin {\n        margin-left: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        margin-left: 4%;\n      } \n      .row.content-area {\n        padding: 0px 5px;\n      }\n\n      .text-right.border-0 > h4 {\n        padding-right: 20px;\n      }\n\n      .keydiagram {\n        width: 100%;\n        text-align: center;\n        margin-left: 0px !important;\n      }\n    }\n    @media (max-width: 1024px) {\n      .keydiagram {\n        width: 100%;\n        margin-left: 9%;\n      }\n      .img-max-width {\n        width: 80% !important;\n      }\n    }\n    @media (max-width: 1023px) {\n      .fixed-report-text-sidebar {\n        position: relative;\n      }\n    }\n\n    .upload-button-size {\n    \tfont-size: 100% !important;\n    }\n  \n  "]
            },] },
];
/**
 * @nocollapse
 */
FileUploadLoaderComponent.ctorParameters = function () { return [
    { type: GlobalsService, },
]; };
FileUploadLoaderComponent.propDecorators = {
    'onFileContentRead': [{ type: Output },],
};
var components$1 = [FileUploadLoaderComponent, ViewUploadLoaderComponent];
var SimulatorLoaderModule = (function () {
    function SimulatorLoaderModule() {
    }
    return SimulatorLoaderModule;
}());
SimulatorLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [components$1],
                providers: [GlobalsService],
                exports: [components$1]
            },] },
];
/**
 * @nocollapse
 */
SimulatorLoaderModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { AcrAssistSimulatorModule, SimulatorLoaderModule, AcrAssistSimulatorComponent as ɵc, AssistChoiceElementComponent as ɵo, AssistDataElementComponent as ɵl, AssistMultiChoiceElementComponent as ɵp, AssistNumericElementComponent as ɵn, HintDiagramComponent as ɵm, ImageMapComponent as ɵq, AssistReportTextComponent as ɵr, CreationServiceInjectorToken as ɵe, ArrayCheckerService as ɵg, ChoiceDataElementCreationService as ɵs, ComputedDataElementCreationService as ɵx, ComputedValueCreationService as ɵk, ConditionsCreationService as ɵj, DataElementCreationBaseService as ɵh, DecisionPointsCreationService as ɵi, DiagramService as ɵf, GlobalValueCreationService as ɵw, IntegerDataElementCreationService as ɵv, MultipleChoiceDataElementCreationService as ɵt, NumericDataElementCreationService as ɵu, TemplateManagerService as ɵd, CoreModule as ɵa, SimulatorEngineService as ɵb, FileUploadLoaderComponent as ɵy, GlobalsService as ɵz, ViewUploadLoaderComponent as ɵba };
//# sourceMappingURL=acr-assist-simulator-test.es5.js.map
